@@ -6,11 +6,11 @@
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @date    Tue, 20 Jul 2010
-/// @version $Id: activitygen_main.cpp 16275 2014-04-29 11:43:40Z behrisch $
+/// @version $Id: activitygen_main.cpp 17235 2014-11-03 10:53:02Z behrisch $
 ///
 // Main object of the ActivityGen application
 /****************************************************************************/
-// SUMO, Simulation of Urban MObility; see http://sumo-sim.org/
+// SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
 // Copyright (C) 2001-2014 DLR (http://www.dlr.de/) and contributors
 // activitygen module
 // Copyright 2010 TUM (Technische Universitaet Muenchen, http://www.tum.de/)
@@ -98,8 +98,13 @@ loadNet(RONet& toFill, ROAbstractEdgeBuilder& eb) {
 
 int
 main(int argc, char* argv[]) {
-    int ret = 0;
     OptionsCont& oc = OptionsCont::getOptions();
+    // give some application descriptions
+    oc.setApplicationDescription(
+        "Generates routes of persons throughout a day for the microscopic road traffic simulation SUMO.");
+    oc.setApplicationName("activitygen", "SUMO activitygen Version " + getBuildName(VERSION_STRING));
+    oc.addCopyrightNotice("Copyright (C) 2010-2012 Technische Universitaet Muenchen");
+    int ret = 0;
     RONet* net = 0;
     try {
         // Initialise subsystems and process options
@@ -118,7 +123,7 @@ main(int argc, char* argv[]) {
         net = new RONet();
         RODUAEdgeBuilder builder(oc.getBool("weights.expand"), oc.getBool("weights.interpolate"));
         loadNet(*net, builder);
-        WRITE_MESSAGE("Loaded " + toString(net->getEdgeNoWithoutInternal()) + " edges.");
+        WRITE_MESSAGE("Loaded " + toString(net->getEdgeNo()) + " edges.");
         if (oc.getBool("debug")) {
             WRITE_MESSAGE("\n\t ---- begin AcitivtyGen ----\n");
         }
