@@ -6,11 +6,11 @@
 /// @author  Walter Bamberger
 /// @author  Michael Behrisch
 /// @date    July 2010
-/// @version $Id: AGChild.cpp 16005 2014-03-24 12:46:02Z cschmidt87 $
+/// @version $Id: AGChild.cpp 17235 2014-11-03 10:53:02Z behrisch $
 ///
 // Person in age to go to school: linked to a school object
 /****************************************************************************/
-// SUMO, Simulation of Urban MObility; see http://sumo-sim.org/
+// SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
 // Copyright (C) 2010-2014 DLR (http://www.dlr.de/) and contributors
 // activitygen module
 // Copyright 2010 TUM (Technische Universitaet Muenchen, http://www.tum.de/)
@@ -45,7 +45,7 @@
 // method definitions
 // ===========================================================================
 void
-AGChild::print() {
+AGChild::print() const {
     std::cout << "- Child: Age=" << age << " School=" << school << std::endl;
 }
 
