@@ -5,11 +5,11 @@
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @date    Thu, 16.03.2006
-/// @version $Id: RODFNet.cpp 15801 2014-03-04 12:28:27Z behrisch $
+/// @version $Id: RODFNet.cpp 17235 2014-11-03 10:53:02Z behrisch $
 ///
 // A DFROUTER-network
 /****************************************************************************/
-// SUMO, Simulation of Urban MObility; see http://sumo-sim.org/
+// SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
 // Copyright (C) 2001-2014 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
@@ -71,9 +71,9 @@ RODFNet::buildApproachList() {
     for (std::map<std::string, ROEdge*>::const_iterator rit = edges.begin(); rit != edges.end(); ++rit) {
         ROEdge* ce = (*rit).second;
         unsigned int i = 0;
-        unsigned int length_size = ce->getNoFollowing();
+        unsigned int length_size = ce->getNumSuccessors();
         for (i = 0; i < length_size; i++) {
-            ROEdge* help = ce->getFollower(i);
+            ROEdge* help = ce->getSuccessor(i);
             if (find(myDisallowedEdges.begin(), myDisallowedEdges.end(), help->getID()) != myDisallowedEdges.end()) {
                 // edges in sinks will not be used
                 continue;
@@ -343,8 +343,7 @@ RODFNet::computeRoutesFor(ROEdge* edge, RODFRouteDesc& base, int /*no*/,
 
 
 void
-RODFNet::buildRoutes(RODFDetectorCon& detcont, bool allEndFollower,
-                     bool keepUnfoundEnds, bool includeInBetween,
+RODFNet::buildRoutes(RODFDetectorCon& detcont, bool keepUnfoundEnds, bool includeInBetween,
                      bool keepShortestOnly, int maxFollowingLength) const {
     // build needed information first
     buildDetectorEdgeDependencies(detcont);
@@ -376,9 +375,6 @@ RODFNet::buildRoutes(RODFDetectorCon& detcont, bool allEndFollower,
         visited.push_back(e);
         computeRoutesFor(e, rd, 0, keepUnfoundEnds, keepShortestOnly,
                          visited, **i, *routes, detcont, maxFollowingLength, seen);
-        if (allEndFollower) {
-            routes->addAllEndFollower();
-        }
         //!!!routes->removeIllegal(illegals);
         (*i)->addRoutes(routes);
 
