@@ -5,11 +5,11 @@
 /// @author  Michael Behrisch
 /// @author  Andreas Gaubatz
 /// @date    Sept 2002
-/// @version $Id: GUIApplicationWindow.cpp 15748 2014-02-26 11:52:24Z namdre $
+/// @version $Id: GUIApplicationWindow.cpp 17235 2014-11-03 10:53:02Z behrisch $
 ///
 // The main window of the SUMO-gui.
 /****************************************************************************/
-// SUMO, Simulation of Urban MObility; see http://sumo-sim.org/
+// SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
 // Copyright (C) 2001-2014 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
@@ -41,7 +41,9 @@
 
 #include <guisim/GUINet.h>
 #include <guisim/GUILane.h>
+#include <microsim/MSGlobals.h>
 #include <microsim/MSEdge.h>
+#include <microsim/MSVehicle.h>
 
 #include "GUISUMOViewParent.h"
 #include "GUILoadThread.h"
@@ -51,6 +53,7 @@
 #include "GUIEvent_SimulationEnded.h"
 
 #include <utils/common/ToString.h>
+#include <utils/common/RandHelper.h>
 #include <utils/foxtools/MFXUtils.h>
 #include <utils/foxtools/FXLCDLabel.h>
 #include <utils/foxtools/FXRealSpinDial.h>
@@ -76,11 +79,6 @@
 #include "dialogs/GUIDialog_AppSettings.h"
 #include "dialogs/GUIDialog_Breakpoints.h"
 
-#ifndef NO_TRACI
-#include <traci-server/TraCIServer.h>
-#include "TraCIServerAPI_GUI.h"
-#endif
-
 #ifdef CHECK_MEMORY_LEAKS
 #include <foreign/nvwa/debug_new.h>
 #endif
@@ -158,6 +156,11 @@ FXDEFMAP(GUIApplicationWindow) GUIApplicationWindowMap[] = {
 // Object implementation
 FXIMPLEMENT(GUIApplicationWindow, FXMainWindow, GUIApplicationWindowMap, ARRAYNUMBER(GUIApplicationWindowMap))
 
+// ===========================================================================
+// static members
+// ===========================================================================
+MTRand GUIApplicationWindow::myGamingRNG;
+
 // ===========================================================================
 // member method definitions
 // ===========================================================================
@@ -169,7 +172,11 @@ GUIApplicationWindow::GUIApplicationWindow(FXApp* a,
       myAlternateSimDelay(0),
       myRecentNets(a, "nets"), myConfigPattern(configPattern),
       hadDependentBuild(false),
-      myShowTimeAsHMS(false) {
+      myShowTimeAsHMS(false),
+      // game specific
+      myJamSoundTime(60),
+      myWaitingTime(0),
+      myTimeLoss(0) {
     GUIIconSubSys::init(a);
 }
 
@@ -232,12 +239,9 @@ GUIApplicationWindow::dependentBuild(bool game) {
     fillMenuBar();
     if (game) {
         onCmdGaming(0, 0, 0);
-        myMenuBar->hide();
-        myToolBar1->hide();
-        myToolBar2->hide();
-        myToolBar4->hide();
-        myToolBar5->hide();
-        myMessageWindow->hide();
+    } else {
+        myToolBar6->hide();
+        myToolBar7->hide();
     }
     // build additional threads
     myLoadThread = new GUILoadThread(getApp(), this, myEvents, myLoadThreadEvent);
@@ -246,7 +250,7 @@ GUIApplicationWindow::dependentBuild(bool game) {
     // set the status bar
     myStatusbar->getStatusLine()->setText("Ready.");
     // set the caption
-    setTitle(MFXUtils::getTitleText(("SUMO " + std::string(VERSION_STRING)).c_str()));
+    setTitle(MFXUtils::getTitleText(("SUMO " + getBuildName(VERSION_STRING)).c_str()));
 
     // start the simulation-thread (it will loop until the application ends deciding by itself whether to perform a step or not)
     myRunThread->start();
@@ -267,6 +271,11 @@ GUIApplicationWindow::create() {
     myMenuBarDrag->create();
     myToolBarDrag1->create();
     myToolBarDrag2->create();
+    myToolBarDrag3->create();
+    myToolBarDrag4->create();
+    myToolBarDrag5->create();
+    myToolBarDrag6->create();
+    myToolBarDrag7->create();
     myFileMenu->create();
     mySelectByPermissions->create();
     myEditMenu->create();
@@ -313,7 +322,7 @@ GUIApplicationWindow::~GUIApplicationWindow() {
 
     while (!myEvents.empty()) {
         // get the next event
-        GUIEvent* e = static_cast<GUIEvent*>(myEvents.top());
+        GUIEvent* e = myEvents.top();
         myEvents.pop();
         delete e;
     }
@@ -389,7 +398,7 @@ GUIApplicationWindow::fillMenuBar() {
     std::vector<std::string> vehicleClasses = SumoVehicleClassStrings.getStrings();
     for (std::vector<std::string>::iterator it = vehicleClasses.begin(); it != vehicleClasses.end(); ++it) {
         new FXMenuCommand(mySelectByPermissions,
-                (*it).c_str(), NULL, this, MID_EDITCHOSEN);
+                          (*it).c_str(), NULL, this, MID_EDITCHOSEN);
     }
 
     myEditMenu = new FXMenuPane(this);
@@ -412,7 +421,7 @@ GUIApplicationWindow::fillMenuBar() {
                       "Application Settings...\t\tOpen a Dialog for Application Settings editing.",
                       NULL, this, MID_APPSETTINGS);
     new FXMenuCheck(mySettingsMenu,
-                    "Gaming Mode\t\tToggle gaming mode on/off.",
+                    "Gaming Mode\tCtl-G\tToggle gaming mode on/off.",
                     this, MID_GAMING);
     // build Locate menu
     myLocatorMenu = new FXMenuPane(this);
@@ -594,6 +603,32 @@ GUIApplicationWindow::buildToolBars() {
                      ICON_ABOVE_TEXT | BUTTON_TOOLBAR | FRAME_RAISED | LAYOUT_TOP | LAYOUT_LEFT);
 #endif
     }
+    {
+        /// game specific stuff
+        // total waitingTime
+        myToolBarDrag6 = new FXToolBarShell(this, FRAME_NORMAL);
+        myToolBar6 = new FXToolBar(myTopDock, myToolBarDrag6, LAYOUT_DOCK_SAME | LAYOUT_SIDE_TOP | FRAME_RAISED);
+        new FXToolBarGrip(myToolBar6, myToolBar6, FXToolBar::ID_TOOLBARGRIP, TOOLBARGRIP_DOUBLE);
+        new FXLabel(myToolBar6, "Waiting Time:\t\tTime spent waiting accumulated for all vehicles", 0, LAYOUT_TOP | LAYOUT_LEFT);
+        myWaitingTimeLabel = new FXEX::FXLCDLabel(myToolBar6, 13, 0, 0, JUSTIFY_RIGHT);
+        myWaitingTimeLabel->setHorizontal(2);
+        myWaitingTimeLabel->setVertical(6);
+        myWaitingTimeLabel->setThickness(2);
+        myWaitingTimeLabel->setGroove(2);
+        myWaitingTimeLabel->setText("-------------");
+
+        // idealistic time loss
+        myToolBarDrag7 = new FXToolBarShell(this, FRAME_NORMAL);
+        myToolBar7 = new FXToolBar(myTopDock, myToolBarDrag7, LAYOUT_DOCK_SAME | LAYOUT_SIDE_TOP | FRAME_RAISED);
+        new FXToolBarGrip(myToolBar7, myToolBar7, FXToolBar::ID_TOOLBARGRIP, TOOLBARGRIP_DOUBLE);
+        new FXLabel(myToolBar7, "Time Loss:\t\tTime lost due to being unable to drive with maximum speed for all vehicles", 0, LAYOUT_TOP | LAYOUT_LEFT);
+        myTimeLossLabel = new FXEX::FXLCDLabel(myToolBar7, 13, 0, 0, JUSTIFY_RIGHT);
+        myTimeLossLabel->setHorizontal(2);
+        myTimeLossLabel->setVertical(6);
+        myTimeLossLabel->setThickness(2);
+        myTimeLossLabel->setGroove(2);
+        myTimeLossLabel->setText("-------------");
+    }
 }
 
 
@@ -649,7 +684,7 @@ GUIApplicationWindow::onCmdEditChosen(FXObject* menu, FXSelector, void*) {
 
 long
 GUIApplicationWindow::onCmdEditBreakpoints(FXObject*, FXSelector, void*) {
-    GUIDialog_Breakpoints* chooser = new GUIDialog_Breakpoints(this);
+    GUIDialog_Breakpoints* chooser = new GUIDialog_Breakpoints(this, myRunThread->getBreakpoints(), myRunThread->getBreakpointLock());
     chooser->create();
     chooser->show();
     return 1;
@@ -669,7 +704,7 @@ GUIApplicationWindow::onCmdOpenConfiguration(FXObject*, FXSelector, void*) {
     if (opendialog.execute()) {
         gCurrentFolder = opendialog.getDirectory();
         std::string file = opendialog.getFilename().text();
-        load(file, false);
+        loadConfigOrNet(file, false);
         myRecentConfigs.appendFile(file.c_str());
     }
     return 1;
@@ -689,7 +724,7 @@ GUIApplicationWindow::onCmdOpenNetwork(FXObject*, FXSelector, void*) {
     if (opendialog.execute()) {
         gCurrentFolder = opendialog.getDirectory();
         std::string file = opendialog.getFilename().text();
-        load(file, true);
+        loadConfigOrNet(file, true);
         myRecentNets.appendFile(file.c_str());
     }
     return 1;
@@ -698,7 +733,7 @@ GUIApplicationWindow::onCmdOpenNetwork(FXObject*, FXSelector, void*) {
 
 long
 GUIApplicationWindow::onCmdReload(FXObject*, FXSelector, void*) {
-    load("", false, true);
+    loadConfigOrNet("", false, true);
     return 1;
 }
 
@@ -710,7 +745,7 @@ GUIApplicationWindow::onCmdOpenRecent(FXObject* sender, FXSelector, void* data)
         return 1;
     }
     std::string file((const char*)data);
-    load(file, sender == &myRecentNets);
+    loadConfigOrNet(file, sender == &myRecentNets);
     return 1;
 }
 
@@ -891,8 +926,33 @@ long
 GUIApplicationWindow::onCmdGaming(FXObject*, FXSelector, void*) {
     myAmGaming = !myAmGaming;
     if (myAmGaming) {
-        mySimDelayTarget->setValue(1000);
+        myMenuBar->hide();
+        myStatusbar->hide();
+        myToolBar1->hide();
+        myToolBar2->hide();
+        myToolBar4->hide();
+        myToolBar5->hide();
+        myToolBar6->show();
+        myToolBar7->show();
+        myMessageWindow->hide();
+        myLCDLabel->setFgColor(MFXUtils::getFXColor(RGBColor::RED));
+        myWaitingTimeLabel->setFgColor(MFXUtils::getFXColor(RGBColor::RED));
+        myTimeLossLabel->setFgColor(MFXUtils::getFXColor(RGBColor::RED));
+        gSchemeStorage.getDefault().gaming = true;
+    } else {
+        myMenuBar->show();
+        myStatusbar->show();
+        myToolBar1->show();
+        myToolBar2->show();
+        myToolBar4->show();
+        myToolBar5->show();
+        myToolBar6->hide();
+        myToolBar7->hide();
+        myMessageWindow->show();
+        myLCDLabel->setFgColor(MFXUtils::getFXColor(RGBColor::GREEN));
+        gSchemeStorage.getDefault().gaming = false;
     }
+    update();
     return 1;
 }
 
@@ -956,7 +1016,7 @@ void
 GUIApplicationWindow::eventOccured() {
     while (!myEvents.empty()) {
         // get the next event
-        GUIEvent* e = static_cast<GUIEvent*>(myEvents.top());
+        GUIEvent* e = myEvents.top();
         myEvents.pop();
         // process
         switch (e->getOwnType()) {
@@ -990,22 +1050,6 @@ void
 GUIApplicationWindow::handleEvent_SimulationLoaded(GUIEvent* e) {
     myAmLoading = false;
     GUIEvent_SimulationLoaded* ec = static_cast<GUIEvent_SimulationLoaded*>(e);
-    if (ec->myNet != 0) {
-#ifndef NO_TRACI
-        std::map<int, TraCIServer::CmdExecutor> execs;
-        execs[CMD_GET_GUI_VARIABLE] = &TraCIServerAPI_GUI::processGet;
-        execs[CMD_SET_GUI_VARIABLE] = &TraCIServerAPI_GUI::processSet;
-        try {
-            TraCIServer::openSocket(execs);
-        } catch (ProcessError& e) {
-            myMessageWindow->appendText(EVENT_ERROR_OCCURED, e.what());
-            WRITE_ERROR(e.what());
-            delete ec->myNet;
-            ec->myNet = 0;
-        }
-#endif
-    }
-
     // check whether the loading was successfull
     if (ec->myNet == 0) {
         // report failure
@@ -1051,7 +1095,13 @@ GUIApplicationWindow::handleEvent_SimulationLoaded(GUIEvent* e) {
                         mySimDelayTarget->setValue(settings.getDelay());
                     }
                     if (settings.getBreakpoints().size() > 0) {
-                        GUIGlobals::gBreakpoints = settings.getBreakpoints();
+                        myRunThread->getBreakpointLock().lock();
+                        myRunThread->getBreakpoints().assign(settings.getBreakpoints().begin(), settings.getBreakpoints().end());
+                        myRunThread->getBreakpointLock().unlock();
+                    }
+                    myJamSounds = settings.getEventDistribution("jam");
+                    if (settings.getJamSoundTime() > 0) {
+                        myJamSoundTime = settings.getJamSoundTime();
                     }
                 }
             } else {
@@ -1062,11 +1112,11 @@ GUIApplicationWindow::handleEvent_SimulationLoaded(GUIEvent* e) {
                 setTitle("SUMO Traffic Light Game");
             } else {
                 // set simulation name on the caption
-                std::string caption = "SUMO " + std::string(VERSION_STRING);
+                std::string caption = "SUMO " + getBuildName(VERSION_STRING);
                 setTitle(MFXUtils::getTitleText(caption.c_str(), ec->myFile.c_str()));
             }
             // set simulation step begin information
-            updateTimeLCD(ec->myNet->getCurrentTimeStep());
+            myLCDLabel->setText("-------------");
         }
     }
     getApp()->endWaitCursor();
@@ -1082,6 +1132,9 @@ void
 GUIApplicationWindow::handleEvent_SimulationStep(GUIEvent*) {
     updateChildren();
     updateTimeLCD(myRunThread->getNet().getCurrentTimeStep());
+    if (myAmGaming) {
+        checkGamingEvents();
+    }
     update();
 }
 
@@ -1089,7 +1142,7 @@ GUIApplicationWindow::handleEvent_SimulationStep(GUIEvent*) {
 void
 GUIApplicationWindow::handleEvent_Message(GUIEvent* e) {
     GUIEvent_Message* ec = static_cast<GUIEvent_Message*>(e);
-    myMessageWindow->appendText(ec->getOwnType(), ec->getMsg());
+    myMessageWindow->appendMsg(ec->getOwnType(), ec->getMsg());
 }
 
 
@@ -1109,9 +1162,47 @@ GUIApplicationWindow::handleEvent_SimulationEnded(GUIEvent* e) {
 }
 
 
+void
+GUIApplicationWindow::checkGamingEvents() {
+    MSVehicleControl& vc = MSNet::getInstance()->getVehicleControl();
+    MSVehicleControl::constVehIt it = vc.loadedVehBegin();
+    MSVehicleControl::constVehIt end = vc.loadedVehEnd();
+#ifdef HAVE_INTERNAL
+    if (myJamSounds.getOverallProb() > 0) {
+        // play honking sound if some vehicle is waiting too long
+        for (; it != end; ++it) {
+            // XXX use impatience instead of waiting time ?
+            if (it->second->getWaitingTime() > TIME2STEPS(myJamSoundTime)) {
+                const std::string cmd = myJamSounds.get(&myGamingRNG);
+                if (cmd != "") {
+                    // yay! fun with dangerous commands... Never use this over the internet
+                    SysUtils::runHiddenCommand(cmd);
+                    // one sound per simulation step is enough
+                    break;
+                }
+            }
+        }
+    }
+#endif
+    // updated peformance indicators
+
+    for (it = vc.loadedVehBegin(); it != end; ++it) {
+        const MSVehicle* veh = dynamic_cast<MSVehicle*>(it->second);
+        assert(veh != 0);
+        const SUMOReal vmax = MIN2(veh->getVehicleType().getMaxSpeed(), veh->getEdge()->getSpeedLimit());
+        if (veh->isOnRoad() && veh->getSpeed() < SUMO_const_haltingSpeed) {
+            myWaitingTime += DELTA_T;
+        }
+        myTimeLoss += TS * TIME2STEPS(vmax - veh->getSpeed()) / vmax; // may be negative with speedFactor > 1
+        myWaitingTimeLabel->setText(time2string(myWaitingTime).c_str());
+        myTimeLossLabel->setText(time2string(myTimeLoss).c_str());
+    }
+
+}
+
 
 void
-GUIApplicationWindow::load(const std::string& file, bool isNet, bool isReload) {
+GUIApplicationWindow::loadConfigOrNet(const std::string& file, bool isNet, bool isReload) {
     getApp()->beginWaitCursor();
     myAmLoading = true;
     closeAllWindows();
@@ -1120,7 +1211,7 @@ GUIApplicationWindow::load(const std::string& file, bool isNet, bool isReload) {
         setStatusBarText("Reloading.");
     } else {
         gSchemeStorage.saveViewport(0, 0, -1); // recenter view
-        myLoadThread->load(file, isNet);
+        myLoadThread->loadConfigOrNet(file, isNet);
         setStatusBarText("Loading '" + file + "'.");
     }
     update();
@@ -1175,7 +1266,7 @@ GUIApplicationWindow::closeAllWindows() {
     // delete the simulation
     myRunThread->deleteSim();
     // reset the caption
-    setTitle(MFXUtils::getTitleText(("SUMO " + std::string(VERSION_STRING)).c_str()));
+    setTitle(MFXUtils::getTitleText(("SUMO " + getBuildName(VERSION_STRING)).c_str()));
     // delete other children
     while (myTrackerWindows.size() != 0) {
         delete myTrackerWindows[0];
@@ -1212,7 +1303,7 @@ GUIApplicationWindow::getCurrentSimTime() const {
 
 void
 GUIApplicationWindow::loadOnStartup() {
-    load("", false);
+    loadConfigOrNet("", false);
 }
 
 
@@ -1224,7 +1315,12 @@ GUIApplicationWindow::setStatusBarText(const std::string& text) {
 
 
 void
-GUIApplicationWindow::updateTimeLCD(const SUMOTime time) {
+GUIApplicationWindow::updateTimeLCD(SUMOTime time) {
+    time -= DELTA_T; // synchronize displayed time with netstate output
+    if (myAmGaming) {
+        // show time counting backwards
+        time = myRunThread->getSimEndTime() - time;
+    }
     SUMOReal fracSeconds = STEPS2TIME(time);
     const bool hideFraction = myAmGaming || fmod(TS, 1.) == 0.;
     const int BuffSize = 100;
