@@ -5,11 +5,11 @@
 /// @author  Christian Roessel
 /// @author  Michael Behrisch
 /// @date    Sept 2002
-/// @version $Id: GUIApplicationWindow.h 15736 2014-02-25 14:48:37Z namdre $
+/// @version $Id: GUIApplicationWindow.h 17235 2014-11-03 10:53:02Z behrisch $
 ///
 // The main window of the SUMO-gui.
 /****************************************************************************/
-// SUMO, Simulation of Urban MObility; see http://sumo-sim.org/
+// SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
 // Copyright (C) 2001-2014 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
@@ -45,6 +45,7 @@
 #include <utils/gui/windows/GUIMainWindow.h>
 #include <utils/common/ValueRetriever.h>
 #include <utils/common/ValueSource.h>
+#include <utils/common/RandomDistributor.h>
 #include "GUISUMOViewParent.h"
 
 
@@ -233,17 +234,20 @@ protected:
 
 private:
     /** starts to load a simulation */
-    void load(const std::string& file, bool isNet, bool isReload = false);
+    void loadConfigOrNet(const std::string& file, bool isNet, bool isReload = false);
 
     /** this method closes all windows and deletes the current simulation */
     void closeAllWindows();
 
     /// @brief updates the simulation time display
-    void updateTimeLCD(const SUMOTime time);
+    void updateTimeLCD(SUMOTime time);
 
     /** opens a new simulation display */
     GUISUMOAbstractView* openNewView(GUISUMOViewParent::ViewType vt = GUISUMOViewParent::VIEW_2D_OPENGL);
 
+    /// @brief handles additional game-related events
+    void checkGamingEvents();
+
 protected:
     /// FOX needs this for static members
     GUIApplicationWindow() { }
@@ -287,8 +291,7 @@ protected:
 
     /// for some menu detaching fun
     FXToolBarShell* myToolBarDrag1, *myToolBarDrag2, *myToolBarDrag3,
-                    *myToolBarDrag4, *myToolBarDrag5,
-                    *myMenuBarDrag;
+                    *myToolBarDrag4, *myToolBarDrag5, *myMenuBarDrag;
 
     ///
     FXRealSpinDial* mySimDelayTarget;
@@ -297,7 +300,7 @@ protected:
     SUMOTime myAlternateSimDelay;
 
     /// List of got requests
-    MFXEventQue myEvents;
+    MFXEventQue<GUIEvent*> myEvents;
 
     /// The menu used for the MDI-windows
     FXMDIMenu* myMDIMenu;
@@ -331,6 +334,24 @@ protected:
     /// @brief whether to show time as hour:minute:second
     bool myShowTimeAsHMS;
 
+
+    /// @name game related things
+    /// {
+    RandomDistributor<std::string> myJamSounds;
+    /// @brief waiting time after which vehicles trigger jam sounds
+    SUMOReal myJamSoundTime;
+    /// @brief A random number generator used to choose a gaming sound
+    static MTRand myGamingRNG;
+
+    /// performance indicators
+    FXEX::FXLCDLabel* myWaitingTimeLabel;
+    FXEX::FXLCDLabel* myTimeLossLabel;
+    SUMOTime myWaitingTime;
+    SUMOTime myTimeLoss;
+    FXToolBar* myToolBar6, *myToolBar7;
+    FXToolBarShell* myToolBarDrag6, *myToolBarDrag7;
+    ////}
+
 };
 
 
