@@ -4,11 +4,11 @@
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @date    Sept 2002
-/// @version $Id: GUILoadThread.cpp 15816 2014-03-05 08:14:29Z behrisch $
+/// @version $Id: GUILoadThread.cpp 17262 2014-11-04 20:41:44Z behrisch $
 ///
 // Class describing the thread that performs the loading of a simulation
 /****************************************************************************/
-// SUMO, Simulation of Urban MObility; see http://sumo-sim.org/
+// SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
 // Copyright (C) 2001-2014 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
@@ -55,7 +55,9 @@
 #include <guinetload/GUIDetectorBuilder.h>
 #include <guinetload/GUITriggerBuilder.h>
 #include <microsim/output/MSDetectorControl.h>
+#include <microsim/MSGlobals.h>
 #include <microsim/MSFrame.h>
+#include <microsim/MSRouteHandler.h>
 #include "GUIApplicationWindow.h"
 #include "GUILoadThread.h"
 #include "GUIGlobals.h"
@@ -65,6 +67,11 @@
 #include <mesogui/GUIMEVehicleControl.h>
 #endif
 
+#ifndef NO_TRACI
+#include <traci-server/TraCIServer.h>
+#include "TraCIServerAPI_GUI.h"
+#endif
+
 #ifdef CHECK_MEMORY_LEAKS
 #include <foreign/nvwa/debug_new.h>
 #endif // CHECK_MEMORY_LEAKS
@@ -74,7 +81,7 @@
 // member method definitions
 // ===========================================================================
 GUILoadThread::GUILoadThread(FXApp* app, MFXInterThreadEventClient* mw,
-                             MFXEventQue& eq, FXEX::FXThreadEvent& ev)
+                             MFXEventQue<GUIEvent*>& eq, FXEX::FXThreadEvent& ev)
     : FXSingleEventThread(app, mw), myParent(mw), myEventQue(eq),
       myEventThrow(ev) {
     myErrorRetriever = new MsgRetrievingFunction<GUILoadThread>(this, &GUILoadThread::retrieveMessage, MsgHandler::MT_ERROR);
@@ -103,26 +110,42 @@ GUILoadThread::run() {
     // register message callbacks
     MsgHandler::getMessageInstance()->addRetriever(myMessageRetriever);
     MsgHandler::getErrorInstance()->addRetriever(myErrorRetriever);
-    MsgHandler::getWarningInstance()->addRetriever(myWarningRetriever);
+    if (!OptionsCont::getOptions().getBool("no-warnings")) {
+        MsgHandler::getWarningInstance()->addRetriever(myWarningRetriever);
+    }
 
     // try to load the given configuration
-    if (!initOptions()) {
+    try {
+        oc.clear();
+        MSFrame::fillOptions();
+        if (myFile != "") {
+            if (myLoadNet) {
+                oc.set("net-file", myFile);
+            } else {
+                oc.set("configuration-file", myFile);
+            }
+            OptionsIO::getOptions(true, 1, 0);
+        } else {
+            OptionsIO::getOptions(true);
+        }
+        // within gui-based applications, nothing is reported to the console
+        MsgHandler::getMessageInstance()->removeRetriever(&OutputDevice::getDevice("stdout"));
+        MsgHandler::getWarningInstance()->removeRetriever(&OutputDevice::getDevice("stderr"));
+        MsgHandler::getErrorInstance()->removeRetriever(&OutputDevice::getDevice("stderr"));
+        // do this once again to get parsed options
+        MsgHandler::initOutputOptions();
+        XMLSubSys::setValidation(oc.getString("xml-validation"), oc.getString("xml-validation.net"));
+        GUIGlobals::gRunAfterLoad = oc.getBool("start");
+        GUIGlobals::gQuitOnEnd = oc.getBool("quit-on-end");
+        if (!MSFrame::checkOptions()) {
+            throw ProcessError();
+        }
+    } catch (ProcessError& e) {
+        if (std::string(e.what()) != std::string("Process Error") && std::string(e.what()) != std::string("")) {
+            WRITE_ERROR(e.what());
+        }
         // the options are not valid but maybe we want to quit
         GUIGlobals::gQuitOnEnd = oc.getBool("quit-on-end");
-        submitEndAndCleanup(net, simStartTime, simEndTime);
-        return 0;
-    }
-    // within gui-based applications, nothing is reported to the console
-    MsgHandler::getMessageInstance()->removeRetriever(&OutputDevice::getDevice("stdout"));
-    MsgHandler::getWarningInstance()->removeRetriever(&OutputDevice::getDevice("stderr"));
-    MsgHandler::getErrorInstance()->removeRetriever(&OutputDevice::getDevice("stderr"));
-    // do this once again to get parsed options
-    MsgHandler::initOutputOptions();
-    XMLSubSys::setValidation(oc.getString("xml-validation"), oc.getString("xml-validation.net"));
-    GUIGlobals::gRunAfterLoad = oc.getBool("start");
-    GUIGlobals::gQuitOnEnd = oc.getBool("quit-on-end");
-
-    if (!MSFrame::checkOptions()) {
         MsgHandler::getErrorInstance()->inform("Quitting (on error).", false);
         submitEndAndCleanup(net, simStartTime, simEndTime);
         return 0;
@@ -130,7 +153,7 @@ GUILoadThread::run() {
 
     // initialise global settings
     RandHelper::initRandGlobal();
-    RandHelper::initRandGlobal(&MSVehicleControl::myVehicleParamsRNG);
+    RandHelper::initRandGlobal(MSRouteHandler::getParsingRNG());
     MSFrame::setMSGlobals(oc);
     GUITexturesHelper::allowTextures(!oc.getBool("disable-textures"));
     MSVehicleControl* vehControl = 0;
@@ -149,6 +172,14 @@ GUILoadThread::run() {
             new GUIEventControl(),
             new GUIEventControl(),
             new GUIEventControl());
+#ifndef NO_TRACI
+        // need to init TraCI-Server before loading routes to catch VEHICLE_STATE_BUILT
+        std::map<int, TraCIServer::CmdExecutor> execs;
+        execs[CMD_GET_GUI_VARIABLE] = &TraCIServerAPI_GUI::processGet;
+        execs[CMD_SET_GUI_VARIABLE] = &TraCIServerAPI_GUI::processSet;
+        TraCIServer::openSocket(execs);
+#endif
+
         eb = new GUIEdgeControlBuilder();
         GUIDetectorBuilder db(*net);
         NLJunctionControlBuilder jb(*net, db);
@@ -211,35 +242,8 @@ GUILoadThread::submitEndAndCleanup(GUINet* net,
 }
 
 
-bool
-GUILoadThread::initOptions() {
-    try {
-        OptionsCont& oc = OptionsCont::getOptions();
-        oc.clear();
-        MSFrame::fillOptions();
-        if (myFile != "") {
-            if (myLoadNet) {
-                oc.set("net-file", myFile);
-            } else {
-                oc.set("configuration-file", myFile);
-            }
-            OptionsIO::getOptions(true, 1, 0);
-        } else {
-            OptionsIO::getOptions(true);
-        }
-        return true;
-    } catch (ProcessError& e) {
-        if (std::string(e.what()) != std::string("Process Error") && std::string(e.what()) != std::string("")) {
-            WRITE_ERROR(e.what());
-        }
-        MsgHandler::getErrorInstance()->inform("Quitting (on error).", false);
-    }
-    return false;
-}
-
-
 void
-GUILoadThread::load(const std::string& file, bool isNet) {
+GUILoadThread::loadConfigOrNet(const std::string& file, bool isNet) {
     myFile = file;
     myLoadNet = isNet;
     start();
