@@ -6,11 +6,11 @@
 /// @author  Laura Bieker
 /// @author  Andreas Gaubatz
 /// @date    Sept 2002
-/// @version $Id: GUISUMOViewParent.cpp 15692 2014-02-22 09:17:02Z behrisch $
+/// @version $Id: GUISUMOViewParent.cpp 17235 2014-11-03 10:53:02Z behrisch $
 ///
 // A single child window which contains a view of the simulation area
 /****************************************************************************/
-// SUMO, Simulation of Urban MObility; see http://sumo-sim.org/
+// SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
 // Copyright (C) 2001-2014 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
@@ -129,6 +129,16 @@ GUISUMOViewParent::~GUISUMOViewParent() {
 }
 
 
+void
+GUISUMOViewParent::toggleGaming() {
+    if (myParent->isGaming()) {
+        myNavigationToolBar->hide();
+    } else {
+        myNavigationToolBar->show();
+    }
+}
+
+
 long
 GUISUMOViewParent::onCmdMakeSnapshot(FXObject*, FXSelector, void*) {
     // get the new file name
@@ -160,49 +170,41 @@ GUISUMOViewParent::onCmdMakeSnapshot(FXObject*, FXSelector, void*) {
 
 long
 GUISUMOViewParent::onCmdLocate(FXObject*, FXSelector sel, void*) {
-    GUIGlObjectType type;
     std::vector<GUIGlID> ids;
     GUIIcon icon;
     std::string title;
     switch (FXSELID(sel)) {
         case MID_LOCATEJUNCTION:
-            type = GLO_JUNCTION;
             ids = static_cast<GUINet*>(GUINet::getInstance())->getJunctionIDs(myParent->listInternal());
             icon = ICON_LOCATEJUNCTION;
             title = "Junction Chooser";
             break;
         case MID_LOCATEEDGE:
-            type = GLO_EDGE;
             ids = GUIEdge::getIDs(myParent->listInternal());
             icon = ICON_LOCATEEDGE;
             title = "Edge Chooser";
             break;
         case MID_LOCATEVEHICLE:
-            type = GLO_VEHICLE;
             static_cast<GUIVehicleControl&>(MSNet::getInstance()->getVehicleControl()).insertVehicleIDs(ids);
             icon = ICON_LOCATEVEHICLE;
             title = "Vehicle Chooser";
             break;
         case MID_LOCATETLS:
-            type = GLO_TLLOGIC;
             ids = static_cast<GUINet*>(GUINet::getInstance())->getTLSIDs();
             icon = ICON_LOCATETLS;
             title = "Traffic Lights Chooser";
             break;
         case MID_LOCATEADD:
-            type = GLO_ADDITIONAL;
             ids = GUIGlObject_AbstractAdd::getIDList();
             icon = ICON_LOCATEADD;
             title = "Additional Objects Chooser";
             break;
         case MID_LOCATEPOI:
-            type = GLO_POI;
             ids = static_cast<GUIShapeContainer&>(GUINet::getInstance()->getShapeContainer()).getPOIIds();
             icon = ICON_LOCATEPOI;
             title = "POI Chooser";
             break;
         case MID_LOCATEPOLY:
-            type = GLO_POLYGON;
             ids = static_cast<GUIShapeContainer&>(GUINet::getInstance()->getShapeContainer()).getPolygonIDs();
             icon = ICON_LOCATEPOLY;
             title = "Polygon Chooser";
@@ -214,7 +216,7 @@ GUISUMOViewParent::onCmdLocate(FXObject*, FXSelector sel, void*) {
     myLocatorButton->killFocus();
     myLocatorPopup->update();
     GUIDialog_GLObjChooser* chooser = new GUIDialog_GLObjChooser(
-        this, GUIIconSubSys::getIcon(icon), title.c_str(), type, ids, GUIGlObjectStorage::gIDStorage);
+        this, GUIIconSubSys::getIcon(icon), title.c_str(), ids, GUIGlObjectStorage::gIDStorage);
     chooser->create();
     chooser->show();
     return 1;
