@@ -4,11 +4,11 @@
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @date    Oct/Nov 2003
-/// @version $Id: GUITLLogicPhasesTrackerWindow.cpp 15692 2014-02-22 09:17:02Z behrisch $
+/// @version $Id: GUITLLogicPhasesTrackerWindow.cpp 17235 2014-11-03 10:53:02Z behrisch $
 ///
 // A window displaying the phase diagram of a tl-logic
 /****************************************************************************/
-// SUMO, Simulation of Urban MObility; see http://sumo-sim.org/
+// SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
 // Copyright (C) 2001-2014 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
@@ -73,7 +73,7 @@ GUITLLogicPhasesTrackerWindow::GUITLLogicPhasesTrackerPanel::GUITLLogicPhasesTra
     FXComposite* c, GUIMainWindow& app,
     GUITLLogicPhasesTrackerWindow& parent)
     : FXGLCanvas(c, app.getGLVisual(), app.getBuildGLCanvas(), (FXObject*) 0, (FXSelector) 0, LAYOUT_SIDE_TOP | LAYOUT_FILL_X | LAYOUT_FILL_Y/*, 0, 0, 300, 200*/),
-      myParent(&parent), myApplication(&app) {}
+      myParent(&parent) {}
 
 
 GUITLLogicPhasesTrackerWindow::GUITLLogicPhasesTrackerPanel::~GUITLLogicPhasesTrackerPanel() {}
@@ -296,7 +296,9 @@ GUITLLogicPhasesTrackerWindow::drawValues(GUITLLogicPhasesTrackerPanel& caller)
     const SUMOReal width = (SUMOReal) caller.getWidth();
     pfSetScaleXY((SUMOReal)(.08 * 300. / width), (SUMOReal)(.08 * 300. / height));
     const SUMOReal h4 = ((SUMOReal) 4 / height);
+    const SUMOReal h9 = ((SUMOReal) 9 / height);
     const SUMOReal h10 = ((SUMOReal) 10 / height);
+    const SUMOReal h11 = ((SUMOReal) 11 / height);
     const SUMOReal h16 = ((SUMOReal) 16 / height);
     const SUMOReal h20 = ((SUMOReal) 20 / height);
     // draw the link names and the lines dividing them
@@ -366,10 +368,13 @@ GUITLLogicPhasesTrackerWindow::drawValues(GUITLLogicPhasesTrackerPanel& caller)
             GLHelper::setColor(getLinkColor(state));
             switch (state) {
                 case LINKSTATE_TL_RED:
+                case LINKSTATE_TL_REDYELLOW:
                     // draw a thin line
-                    glBegin(GL_LINES);
-                    glVertex2d(x, h - h10);
-                    glVertex2d(x2, h - h10);
+                    glBegin(GL_QUADS);
+                    glVertex2d(x, h - h11);
+                    glVertex2d(x, h - h9);
+                    glVertex2d(x2, h - h9);
+                    glVertex2d(x2, h - h11);
                     glEnd();
                     break;
                 default:
@@ -406,7 +411,7 @@ GUITLLogicPhasesTrackerWindow::drawValues(GUITLLogicPhasesTrackerPanel& caller)
             t -= (SUMOReal)((width - 31.) / 4.);
         }
         // draw time information
-        h = (SUMOReal)(myTLLogic->getLinks().size() * 20 + 12);
+        //h = (SUMOReal)(myTLLogic->getLinks().size() * 20 + 12);
         SUMOReal glh = (SUMOReal)(1.0 - myTLLogic->getLinks().size() * h20 - h10);
         // current begin time
         pfSetScaleXY((SUMOReal)(.05 * 300. / width), (SUMOReal)(.05 * 300. / height));
