@@ -5,11 +5,11 @@
 /// @author  Michael Behrisch
 /// @author  Laura Bieker
 /// @date    Sept 2002
-/// @version $Id: GUIEdge.cpp 16290 2014-05-05 12:38:38Z namdre $
+/// @version $Id: GUIEdge.cpp 17271 2014-11-05 11:12:48Z namdre $
 ///
 // A road/street connecting two junctions (gui-version)
 /****************************************************************************/
-// SUMO, Simulation of Urban MObility; see http://sumo-sim.org/
+// SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
 // Copyright (C) 2001-2014 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
@@ -53,6 +53,7 @@
 #include <microsim/logging/CastingFunctionBinding.h>
 #include <microsim/logging/FunctionBinding.h>
 #include "GUIEdge.h"
+#include "GUIVehicle.h"
 #include "GUINet.h"
 #include "GUILane.h"
 #include "GUIPerson.h"
@@ -73,8 +74,9 @@
 // included modules
 // ===========================================================================
 GUIEdge::GUIEdge(const std::string& id, int numericalID,
-                 const EdgeBasicFunction function, const std::string& streetName, const std::string& edgeType)
-    : MSEdge(id, numericalID, function, streetName, edgeType),
+                 const EdgeBasicFunction function,
+                 const std::string& streetName, const std::string& edgeType, int priority)
+    : MSEdge(id, numericalID, function, streetName, edgeType, priority),
       GUIGlObject(GLO_EDGE, id) {}
 
 
@@ -158,7 +160,7 @@ GUIEdge::getParameterWindow(GUIMainWindow& app,
     // add edge items
     ret->mkItem("length [m]", false, (*myLanes)[0]->getLength());
     ret->mkItem("allowed speed [m/s]", false, getAllowedSpeed());
-    ret->mkItem("occupancy [%]", true, new FunctionBinding<GUIEdge, SUMOReal>(this, &GUIEdge::getBruttoOccupancy));
+    ret->mkItem("occupancy [%]", true, new FunctionBinding<GUIEdge, SUMOReal>(this, &GUIEdge::getBruttoOccupancy, 100.));
     ret->mkItem("mean vehicle speed [m/s]", true, new FunctionBinding<GUIEdge, SUMOReal>(this, &GUIEdge::getMeanSpeed));
     ret->mkItem("flow [veh/h/lane]", true, new FunctionBinding<GUIEdge, SUMOReal>(this, &GUIEdge::getFlow));
     ret->mkItem("#vehicles", true, new CastingFunctionBinding<GUIEdge, SUMOReal, unsigned int>(this, &GUIEdge::getVehicleNo));
@@ -198,9 +200,7 @@ GUIEdge::drawGL(const GUIVisualizationSettings& s) const {
     if (s.hideConnectors && myFunction == MSEdge::EDGEFUNCTION_CONNECTOR) {
         return;
     }
-    if (MSGlobals::gUseMesoSim) {
-        glPushName(getGlID());
-    }
+    glPushName(getGlID());
     // draw the lanes
     for (std::vector<MSLane*>::const_iterator i = myLanes->begin(); i != myLanes->end(); ++i) {
 #ifdef HAVE_INTERNAL
@@ -215,81 +215,12 @@ GUIEdge::drawGL(const GUIVisualizationSettings& s) const {
     }
 #ifdef HAVE_INTERNAL
     if (MSGlobals::gUseMesoSim) {
-        const GUIVisualizationTextSettings& nameSettings = s.vehicleName;
-        GUIMEVehicleControl* vehicleControl = GUINet::getGUIInstance()->getGUIMEVehicleControl();
-        if (vehicleControl != 0) {
-            // draw the meso vehicles
-            vehicleControl->secureVehicles();
-            size_t laneIndex = 0;
-            MESegment::Queue queue;
-            for (std::vector<MSLane*>::const_iterator msl = myLanes->begin(); msl != myLanes->end(); ++msl, ++laneIndex) {
-                GUILane* l = static_cast<GUILane*>(*msl);
-                const PositionVector& shape = l->getShape();
-                const std::vector<SUMOReal>& shapeRotations = l->getShapeRotations();
-                const std::vector<SUMOReal>& shapeLengths = l->getShapeLengths();
-                const Position& laneBeg = shape[0];
-                glPushMatrix();
-                glTranslated(laneBeg.x(), laneBeg.y(), 0);
-                glRotated(shapeRotations[0], 0, 0, 1);
-                // go through the vehicles
-                int shapeIndex = 0;
-                SUMOReal shapeOffset = 0; // ofset at start of current shape
-                SUMOReal segmentOffset = 0; // offset at start of current segment
-                for (MESegment* segment = MSGlobals::gMesoNet->getSegmentForEdge(*this);
-                        segment != 0; segment = segment->getNextSegment()) {
-                    const SUMOReal length = segment->getLength();
-                    if (laneIndex < segment->numQueues()) {
-                        // make a copy so we don't have to worry about synchronization
-                        queue = segment->getQueue(laneIndex);
-                        const SUMOReal avgCarSize = segment->getBruttoOccupancy() / segment->getCarNumber();
-                        const size_t queueSize = queue.size();
-                        for (size_t i = 0; i < queueSize; ++i) {
-                            MSBaseVehicle* veh = queue[queueSize - i - 1];
-                            setVehicleColor(s, veh);
-                            SUMOReal vehiclePosition = segmentOffset + length - i * avgCarSize;
-                            SUMOReal xOff = 0.f;
-                            while (vehiclePosition < segmentOffset) {
-                                // if there is only a single queue for a
-                                // multi-lane edge shift vehicles and start
-                                // drawing again from the end of the segment
-                                vehiclePosition += length;
-                                xOff += 0.5f;
-                            }
-                            while (shapeIndex < (int)shapeRotations.size() - 1 && vehiclePosition > shapeOffset + shapeLengths[shapeIndex]) {
-                                glPopMatrix();
-                                shapeOffset += shapeLengths[shapeIndex];
-                                shapeIndex++;
-                                glPushMatrix();
-                                glTranslated(shape[shapeIndex].x(), shape[shapeIndex].y(), 0);
-                                glRotated(shapeRotations[shapeIndex], 0, 0, 1);
-                            }
-                            glPushMatrix();
-                            glTranslated(xOff, -(vehiclePosition - shapeOffset), GLO_VEHICLE);
-                            glPushMatrix();
-                            glScaled(1, avgCarSize, 1);
-                            glBegin(GL_TRIANGLES);
-                            glVertex2d(0, 0);
-                            glVertex2d(0 - 1.25, 1);
-                            glVertex2d(0 + 1.25, 1);
-                            glEnd();
-                            glPopMatrix();
-                            glPopMatrix();
-                            if (nameSettings.show) {
-                                GLHelper::drawText(veh->getID(),
-                                                   Position(xOff, -(vehiclePosition - shapeOffset)),
-                                                   GLO_MAX, nameSettings.size / s.scale, nameSettings.color, 0);
-                            }
-                        }
-                    }
-                    segmentOffset += length;
-                }
-                glPopMatrix();
-            }
-            vehicleControl->releaseVehicles();
+        if (s.scale * s.vehicleSize.getExaggeration(s) > s.vehicleSize.minSize) {
+            drawMesoVehicles(s);
         }
-        glPopName();
     }
 #endif
+    glPopName();
     // (optionally) draw the name and/or the street name
     const bool drawEdgeName = s.edgeName.show && myFunction == EDGEFUNCTION_NORMAL;
     const bool drawInternalEdgeName = s.internalEdgeName.show && myFunction == EDGEFUNCTION_INTERNAL;
@@ -320,7 +251,7 @@ GUIEdge::drawGL(const GUIVisualizationSettings& s) const {
             }
         }
     }
-    if (s.scale > s.minPersonSize) {
+    if (s.scale * s.personSize.getExaggeration(s) > s.personSize.minSize) {
         myLock.lock();
         for (std::set<MSPerson*>::const_iterator i = myPersons.begin(); i != myPersons.end(); ++i) {
             GUIPerson* person = dynamic_cast<GUIPerson*>(*i);
@@ -331,7 +262,86 @@ GUIEdge::drawGL(const GUIVisualizationSettings& s) const {
     }
 }
 
+
 #ifdef HAVE_INTERNAL
+void
+GUIEdge::drawMesoVehicles(const GUIVisualizationSettings& s) const {
+    const GUIVisualizationTextSettings& nameSettings = s.vehicleName;
+    GUIMEVehicleControl* vehicleControl = GUINet::getGUIInstance()->getGUIMEVehicleControl();
+    if (vehicleControl != 0) {
+        // draw the meso vehicles
+        vehicleControl->secureVehicles();
+        size_t laneIndex = 0;
+        MESegment::Queue queue;
+        for (std::vector<MSLane*>::const_iterator msl = myLanes->begin(); msl != myLanes->end(); ++msl, ++laneIndex) {
+            GUILane* l = static_cast<GUILane*>(*msl);
+            const PositionVector& shape = l->getShape();
+            const std::vector<SUMOReal>& shapeRotations = l->getShapeRotations();
+            const std::vector<SUMOReal>& shapeLengths = l->getShapeLengths();
+            const Position& laneBeg = shape[0];
+            glPushMatrix();
+            glTranslated(laneBeg.x(), laneBeg.y(), 0);
+            glRotated(shapeRotations[0], 0, 0, 1);
+            // go through the vehicles
+            int shapeIndex = 0;
+            SUMOReal shapeOffset = 0; // ofset at start of current shape
+            SUMOReal segmentOffset = 0; // offset at start of current segment
+            for (MESegment* segment = MSGlobals::gMesoNet->getSegmentForEdge(*this);
+                    segment != 0; segment = segment->getNextSegment()) {
+                const SUMOReal length = segment->getLength() * segment->getLengthGeometryFactor();
+                if (laneIndex < segment->numQueues()) {
+                    // make a copy so we don't have to worry about synchronization
+                    queue = segment->getQueue(laneIndex);
+                    const SUMOReal avgCarSize = segment->getBruttoOccupancy() / segment->getCarNumber();
+                    const size_t queueSize = queue.size();
+                    for (size_t i = 0; i < queueSize; ++i) {
+                        MSBaseVehicle* veh = queue[queueSize - i - 1];
+                        setVehicleColor(s, veh);
+                        SUMOReal vehiclePosition = segmentOffset + length - i * avgCarSize;
+                        SUMOReal xOff = 0.f;
+                        while (vehiclePosition < segmentOffset) {
+                            // if there is only a single queue for a
+                            // multi-lane edge shift vehicles and start
+                            // drawing again from the end of the segment
+                            vehiclePosition += length;
+                            xOff += 0.5f;
+                        }
+                        while (shapeIndex < (int)shapeRotations.size() - 1 && vehiclePosition > shapeOffset + shapeLengths[shapeIndex]) {
+                            glPopMatrix();
+                            shapeOffset += shapeLengths[shapeIndex];
+                            shapeIndex++;
+                            glPushMatrix();
+                            glTranslated(shape[shapeIndex].x(), shape[shapeIndex].y(), 0);
+                            glRotated(shapeRotations[shapeIndex], 0, 0, 1);
+                        }
+                        glPushMatrix();
+                        glTranslated(xOff, -(vehiclePosition - shapeOffset), GLO_VEHICLE);
+                        glPushMatrix();
+                        glScaled(1, avgCarSize, 1);
+                        glBegin(GL_TRIANGLES);
+                        glVertex2d(0, 0);
+                        glVertex2d(0 - 1.25, 1);
+                        glVertex2d(0 + 1.25, 1);
+                        glEnd();
+                        glPopMatrix();
+                        glPopMatrix();
+                        if (nameSettings.show) {
+                            GLHelper::drawText(veh->getID(),
+                                               Position(xOff, -(vehiclePosition - shapeOffset)),
+                                               GLO_MAX, nameSettings.size / s.scale, nameSettings.color, 0);
+                        }
+                    }
+                }
+                segmentOffset += length;
+            }
+            glPopMatrix();
+        }
+        vehicleControl->releaseVehicles();
+    }
+}
+
+
+
 unsigned int
 GUIEdge::getVehicleNo() const {
     size_t vehNo = 0;
@@ -433,6 +443,26 @@ GUIEdge::getColorValue(size_t activeScheme) const {
 }
 
 
+SUMOReal
+GUIEdge::getScaleValue(size_t activeScheme) const {
+    switch (activeScheme) {
+        case 1:
+            return gSelected.isSelected(getType(), getGlID());
+        case 2:
+            return getAllowedSpeed();
+        case 3:
+            return getBruttoOccupancy();
+        case 4:
+            return getMeanSpeed();
+        case 5:
+            return getFlow();
+        case 6:
+            return getRelativeSpeed();
+    }
+    return 0;
+}
+
+
 MESegment*
 GUIEdge::getSegmentAtPosition(const Position& pos) {
     const PositionVector& shape = getLanes()[0]->getShape();
@@ -444,32 +474,61 @@ GUIEdge::getSegmentAtPosition(const Position& pos) {
 void
 GUIEdge::setVehicleColor(const GUIVisualizationSettings& s, MSBaseVehicle* veh) const {
     const GUIColorer& c = s.vehicleColorer;
-    switch (c.getActive()) {
-        case 0:
-            if (veh->getParameter().wasSet(VEHPARS_COLOR_SET)) {
-                GLHelper::setColor(veh->getParameter().color);
-            }
-            if (veh->getVehicleType().wasSet(VTYPEPARS_COLOR_SET)) {
-                GLHelper::setColor(veh->getVehicleType().getColor());
-            }
-            if (veh->getRoute().getColor() != RGBColor::DEFAULT_COLOR) {
-                GLHelper::setColor(veh->getRoute().getColor());
-            }
-            break;
-        case 2:
-            GLHelper::setColor(veh->getParameter().color);
-            break;
-        case 4:
-            GLHelper::setColor(veh->getVehicleType().getColor());
-            break;
-        case 5:
-            GLHelper::setColor(veh->getRoute().getColor());
-            break;
-        default:
-            GLHelper::setColor(c.getScheme().getColor(0));
+    if (!GUIVehicle::setFunctionalColor(c.getActive(), veh)) {
+        GLHelper::setColor(c.getScheme().getColor(getVehicleColorValue(c.getActive(), veh)));
     }
 }
 
+
+SUMOReal
+GUIEdge::getVehicleColorValue(size_t activeScheme, MSBaseVehicle* veh) const {
+    switch (activeScheme) {
+        case 8:
+            return veh->getSpeed();
+        case 9:
+            return STEPS2TIME(veh->getWaitingTime());
+        case 10:
+            return 0; // invalid getLastLaneChangeOffset();
+        case 11:
+            return MIN2(veh->getMaxSpeed(), getVehicleMaxSpeed(veh));
+        case 12:
+            return 0; // invalid getCO2Emissions();
+        case 13:
+            return 0; // invalid getCOEmissions();
+        case 14:
+            return 0; // invalid getPMxEmissions();
+        case 15:
+            return 0; // invalid  getNOxEmissions();
+        case 16:
+            return 0; // invalid getHCEmissions();
+        case 17:
+            return 0; // invalid getFuelConsumption();
+        case 18:
+            return 0; // invalid getHarmonoise_NoiseEmissions();
+        case 19: // !!! unused!?
+            if (veh->getNumberReroutes() == 0) {
+                return -1;
+            }
+            return veh->getNumberReroutes();
+        case 20:
+            return 0; // invalid gSelected.isSelected(GLO_VEHICLE, getGlID());
+        case 21:
+            return 0; // invalid getBestLaneOffset();
+        case 22:
+            return 0; // invalid getAcceleration();
+        case 23:
+            return 0; // invalid getTimeGap();
+    }
+    return 0;
+}
+
+
+
+
+
+
+
+
 #endif
 
 /****************************************************************************/
