@@ -5,11 +5,11 @@
 /// @author  Sascha Krieg
 /// @author  Michael Behrisch
 /// @date    Sept 2002
-/// @version $Id: GUIEdge.h 16290 2014-05-05 12:38:38Z namdre $
+/// @version $Id: GUIEdge.h 17271 2014-11-05 11:12:48Z namdre $
 ///
 // A road/street connecting two junctions (gui-version)
 /****************************************************************************/
-// SUMO, Simulation of Urban MObility; see http://sumo-sim.org/
+// SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
 // Copyright (C) 2001-2014 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
@@ -66,7 +66,8 @@ public:
      * @see MSEdge
      */
     GUIEdge(const std::string& id, int numericalID,
-            const EdgeBasicFunction function, const std::string& streetName, const std::string& edgeType);
+            const EdgeBasicFunction function,
+            const std::string& streetName, const std::string& edgeType, int priority);
 
 
     /// @brief Destructor.
@@ -165,12 +166,20 @@ public:
     /// @brief gets the color value according to the current scheme index
     SUMOReal getColorValue(size_t activeScheme) const;
 
+    /// @brief gets the scaling value according to the current scheme index
+    SUMOReal getScaleValue(size_t activeScheme) const;
+
     /// @brief returns the segment closest to the given position
     MESegment* getSegmentAtPosition(const Position& pos);
 
     /// @brief sets the vehicle color according to the currente settings
     void setVehicleColor(const GUIVisualizationSettings& s, MSBaseVehicle* veh) const;
 
+    /// @brief gets the vehicle color value according to the current scheme index
+    SUMOReal getVehicleColorValue(size_t activeScheme, MSBaseVehicle* veh) const;
+
+    void drawMesoVehicles(const GUIVisualizationSettings& s) const;
+
 #endif
 
 
