@@ -4,11 +4,11 @@
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @date    Sept 2002
-/// @version $Id: GUILane.cpp 15753 2014-02-26 13:11:10Z namdre $
+/// @version $Id: GUILane.cpp 17292 2014-11-07 08:24:09Z namdre $
 ///
 // Representation of a lane in the micro simulation (gui-version)
 /****************************************************************************/
-// SUMO, Simulation of Urban MObility; see http://sumo-sim.org/
+// SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
 // Copyright (C) 2001-2014 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
@@ -44,6 +44,7 @@
 #include <utils/gui/windows/GUISUMOAbstractView.h>
 #include <utils/gui/div/GUIParameterTableWindow.h>
 #include <utils/gui/div/GUIGlobalSelection.h>
+#include <microsim/MSGlobals.h>
 #include <microsim/MSLane.h>
 #include <microsim/MSVehicleControl.h>
 #include <microsim/MSVehicleTransfer.h>
@@ -62,6 +63,7 @@
 #include <foreign/nvwa/debug_new.h>
 #endif // CHECK_MEMORY_LEAKS
 
+//#define GUILane_DEBUG_DRAW_WALKING_AREA_VERTICES
 
 // ===========================================================================
 // method definitions
@@ -135,9 +137,9 @@ GUILane::executeMovements(SUMOTime t, std::vector<MSLane*>& into) {
 
 
 MSVehicle*
-GUILane::removeVehicle(MSVehicle* remVehicle, MSMoveReminder::Notification notification) {
+GUILane::removeVehicle(MSVehicle* remVehicle, MSMoveReminder::Notification notification, bool notify) {
     AbstractMutex::ScopedLocker locker(myLock);
-    return MSLane::removeVehicle(remVehicle, notification);
+    return MSLane::removeVehicle(remVehicle, notification, notify);
 }
 
 
@@ -170,23 +172,23 @@ GUILane::drawLinkNo() const {
         return;
     }
     // draw all links
+    if (getEdge().isCrossing()) {
+        // draw indices at the start and end of the crossing
+        MSLink* link = MSLinkContHelper::getConnectingLink(*getLogicalPredecessorLane(), *this);
+        PositionVector shape = getShape();
+        shape.extrapolate(0.5); // draw on top of the walking area
+        drawTextAtEnd(toString(link->getIndex()), shape, 0);
+        drawTextAtEnd(toString(link->getIndex()), shape.reverse(), 0);
+        return;
+    }
+    // draw all links
     SUMOReal w = myWidth / (SUMOReal) noLinks;
     SUMOReal x1 = myHalfLaneWidth;
-    glPushMatrix();
-    const PositionVector& g = getShape();
-    const Position& end = g.back();
-    const Position& f = g[-2];
-    const Position& s = end;
-    const SUMOReal rot = RAD2DEG(atan2((s.x() - f.x()), (f.y() - s.y())));
-    glTranslated(end.x(), end.y(), 0);
-    glRotated(rot, 0, 0, 1);
     for (int i = noLinks; --i >= 0;) {
         SUMOReal x2 = x1 - (SUMOReal)(w / 2.);
-        GLHelper::drawText(toString(myLinks[i]->getIndex()),
-                           Position(x2, 0), 0, .6, RGBColor(128, 128, 255, 255), 180);
+        drawTextAtEnd(toString(myLinks[i]->getIndex()), getShape(), x2);
         x1 -= w;
     }
-    glPopMatrix();
 }
 
 
@@ -196,27 +198,42 @@ GUILane::drawTLSLinkNo(const GUINet& net) const {
     if (noLinks == 0) {
         return;
     }
+    if (getEdge().isCrossing()) {
+        // draw indices at the start and end of the crossing
+        MSLink* link = MSLinkContHelper::getConnectingLink(*getLogicalPredecessorLane(), *this);
+        int linkNo = net.getLinkTLIndex(link);
+        if (linkNo >= 0) {
+            PositionVector shape = getShape();
+            shape.extrapolate(0.5); // draw on top of the walking area
+            drawTextAtEnd(toString(linkNo), shape, 0);
+            drawTextAtEnd(toString(linkNo), shape.reverse(), 0);
+        }
+        return;
+    }
     // draw all links
     SUMOReal w = myWidth / (SUMOReal) noLinks;
     SUMOReal x1 = myHalfLaneWidth;
-    glPushMatrix();
-    const PositionVector& g = getShape();
-    const Position& end = g.back();
-    const Position& f = g[-2];
-    const Position& s = end;
-    const SUMOReal rot = RAD2DEG(atan2((s.x() - f.x()), (f.y() - s.y())));
-    glTranslated(end.x(), end.y(), 0);
-    glRotated(rot, 0, 0, 1);
     for (int i = noLinks; --i >= 0;) {
         SUMOReal x2 = x1 - (SUMOReal)(w / 2.);
         int linkNo = net.getLinkTLIndex(myLinks[i]);
         if (linkNo < 0) {
             continue;
         }
-        GLHelper::drawText(toString(linkNo),
-                           Position(x2, 0), 0, .6, RGBColor(128, 128, 255, 255), 180);
+        drawTextAtEnd(toString(linkNo), getShape(), x2);
         x1 -= w;
     }
+}
+
+
+void
+GUILane::drawTextAtEnd(const std::string& text, const PositionVector& shape, SUMOReal x) const {
+    glPushMatrix();
+    const Position& end = shape.back();
+    const Position& f = shape[-2];
+    const SUMOReal rot = RAD2DEG(atan2((end.x() - f.x()), (f.y() - end.y())));
+    glTranslated(end.x(), end.y(), 0);
+    glRotated(rot, 0, 0, 1);
+    GLHelper::drawText(text, Position(x, 0), 0, .6, RGBColor(128, 128, 255, 255), 180);
     glPopMatrix();
 }
 
@@ -224,13 +241,36 @@ GUILane::drawTLSLinkNo(const GUINet& net) const {
 void
 GUILane::drawLinkRules(const GUINet& net) const {
     unsigned int noLinks = (unsigned int)myLinks.size();
-    const PositionVector& g = getShape();
-    const Position& end = g.back();
-    const Position& f = g[-2];
-    const Position& s = end;
-    const SUMOReal rot = RAD2DEG(atan2((s.x() - f.x()), (f.y() - s.y())));
     if (noLinks == 0) {
-        glPushName(getGlID());
+        drawLinkRule(net, 0, getShape(), 0, 0);
+        return;
+    }
+    if (getEdge().isCrossing()) {
+        // draw rules at the start and end of the crossing
+        MSLink* link = MSLinkContHelper::getConnectingLink(*getLogicalPredecessorLane(), *this);
+        PositionVector shape = getShape();
+        shape.extrapolate(0.5); // draw on top of the walking area
+        drawLinkRule(net, link, shape, 0, myWidth);
+        drawLinkRule(net, link, shape.reverse(), 0, myWidth);
+        return;
+    }
+    // draw all links
+    SUMOReal w = myWidth / (SUMOReal) noLinks;
+    SUMOReal x1 = 0;
+    for (unsigned int i = 0; i < noLinks; ++i) {
+        SUMOReal x2 = x1 + w;
+        drawLinkRule(net, myLinks[i], getShape(), x1, x2);
+        x1 = x2;
+    }
+}
+
+
+void
+GUILane::drawLinkRule(const GUINet& net, MSLink* link, const PositionVector& shape, SUMOReal x1, SUMOReal x2) const {
+    const Position& end = shape.back();
+    const Position& f = shape[-2];
+    const SUMOReal rot = RAD2DEG(atan2((end.x() - f.x()), (f.y() - end.y())));
+    if (link == 0) {
         GLHelper::setColor(getLinkColor(LINKSTATE_DEADEND));
         glPushMatrix();
         glTranslated(end.x(), end.y(), 0);
@@ -242,24 +282,16 @@ GUILane::drawLinkRules(const GUINet& net) const {
         glVertex2d(myHalfLaneWidth, 0.0);
         glEnd();
         glPopMatrix();
-        glPopName();
-        return;
-    }
-    // draw all links
-    const bool railway = isRailway(myPermissions);
-    SUMOReal w = myWidth / (SUMOReal) noLinks;
-    SUMOReal x1 = 0;
-    glPushMatrix();
-    glTranslated(end.x(), end.y(), 0);
-    glRotated(rot, 0, 0, 1);
-    for (unsigned int i = 0; i < noLinks; ++i) {
-        SUMOReal x2 = x1 + w;
-        MSLink* link = myLinks[i];
+    } else {
+        glPushMatrix();
+        glTranslated(end.x(), end.y(), 0);
+        glRotated(rot, 0, 0, 1);
         // select glID
         switch (link->getState()) {
             case LINKSTATE_TL_GREEN_MAJOR:
             case LINKSTATE_TL_GREEN_MINOR:
             case LINKSTATE_TL_RED:
+            case LINKSTATE_TL_REDYELLOW:
             case LINKSTATE_TL_YELLOW_MAJOR:
             case LINKSTATE_TL_YELLOW_MINOR:
             case LINKSTATE_TL_OFF_BLINKING:
@@ -274,7 +306,7 @@ GUILane::drawLinkRules(const GUINet& net) const {
                 break;
         }
         GLHelper::setColor(getLinkColor(link->getState()));
-        if (!railway || link->getState() != LINKSTATE_MAJOR) {
+        if (!isRailway(myPermissions) || link->getState() != LINKSTATE_MAJOR) {
             // THE WHITE BAR SHOULD BE THE DEFAULT FOR MOST RAILWAY
             // LINKS AND LOOKS UGLY SO WE DO NOT DRAW IT
             glBegin(GL_QUADS);
@@ -285,13 +317,10 @@ GUILane::drawLinkRules(const GUINet& net) const {
             glEnd();
         }
         glPopName();
-        x1 = x2;
-        x2 += w;
+        glPopMatrix();
     }
-    glPopMatrix();
 }
 
-
 void
 GUILane::drawArrows() const {
     if (myLinks.size() == 0) {
@@ -302,10 +331,12 @@ GUILane::drawArrows() const {
     const Position& f = getShape()[-2];
     const SUMOReal rot = RAD2DEG(atan2((end.x() - f.x()), (f.y() - end.y())));
     glPushMatrix();
-    glPushName(0);
     glColor3d(1, 1, 1);
     glTranslated(end.x(), end.y(), 0);
     glRotated(rot, 0, 0, 1);
+    if (myWidth < SUMO_const_laneWidth) {
+        glScaled(myWidth / SUMO_const_laneWidth, 1, 1);
+    }
     for (std::vector<MSLink*>::const_iterator i = myLinks.begin(); i != myLinks.end(); ++i) {
         LinkDirection dir = (*i)->getDirection();
         LinkState state = (*i)->getState();
@@ -348,56 +379,17 @@ GUILane::drawArrows() const {
         }
     }
     glPopMatrix();
-    glPopName();
 }
 
 
 void
 GUILane::drawLane2LaneConnections() const {
     for (std::vector<MSLink*>::const_iterator i = myLinks.begin(); i != myLinks.end(); ++i) {
-        LinkState state = (*i)->getState();
         const MSLane* connected = (*i)->getLane();
         if (connected == 0) {
             continue;
         }
-        switch (state) {
-            case LINKSTATE_TL_GREEN_MAJOR:
-            case LINKSTATE_TL_GREEN_MINOR:
-                glColor3d(0, 1, 0);
-                break;
-            case LINKSTATE_TL_RED:
-                glColor3d(1, 0, 0);
-                break;
-            case LINKSTATE_TL_YELLOW_MAJOR:
-            case LINKSTATE_TL_YELLOW_MINOR:
-                glColor3d(1, 1, 0);
-                break;
-            case LINKSTATE_TL_OFF_BLINKING:
-                glColor3d(1, 1, 0);
-                break;
-            case LINKSTATE_TL_OFF_NOSIGNAL:
-                glColor3d(0, 1, 1);
-                break;
-            case LINKSTATE_MAJOR:
-                glColor3d(1, 1, 1);
-                break;
-            case LINKSTATE_MINOR:
-                glColor3d(.2, .2, .2);
-                break;
-            case LINKSTATE_STOP:
-                glColor3d(.4, .2, .2);
-                break;
-            case LINKSTATE_EQUAL:
-                glColor3d(.5, .5, .5);
-                break;
-            case LINKSTATE_ALLWAY_STOP:
-                glColor3d(.2, .2, .4);
-                break;
-            case LINKSTATE_DEADEND:
-                glColor3d(0, 0, 0);
-                break;
-        }
-
+        GLHelper::setColor(getLinkColor((*i)->getState()));
         glBegin(GL_LINES);
         const Position& p1 = getShape()[-1];
         const Position& p2 = connected->getShape()[0];
@@ -412,10 +404,20 @@ GUILane::drawLane2LaneConnections() const {
 void
 GUILane::drawGL(const GUIVisualizationSettings& s) const {
     glPushMatrix();
-    const bool isInternal = myEdge->getPurpose() == MSEdge::EDGEFUNCTION_INTERNAL;
+    glPushName(getGlID());
+    const bool isCrossing = myEdge->getPurpose() == MSEdge::EDGEFUNCTION_CROSSING;
+    const bool isWalkingArea = myEdge->getPurpose() == MSEdge::EDGEFUNCTION_WALKINGAREA;
+    const bool isInternal = isCrossing || isWalkingArea || myEdge->getPurpose() == MSEdge::EDGEFUNCTION_INTERNAL;
     bool mustDrawMarkings = false;
-    const bool drawDetails =  s.scale * s.laneWidthExaggeration > 5;
-    if (isInternal) {
+    SUMOReal exaggeration = s.laneWidthExaggeration * s.laneScaler.getScheme().getColor(getScaleValue(s.laneScaler.getActive()));
+#ifdef HAVE_INTERNAL
+    if (MSGlobals::gUseMesoSim) {
+        GUIEdge* myGUIEdge = dynamic_cast<GUIEdge*>(myEdge);
+        exaggeration *= s.edgeScaler.getScheme().getColor(myGUIEdge->getScaleValue(s.edgeScaler.getActive()));
+    }
+#endif
+    const bool drawDetails =  s.scale * exaggeration > 5;
+    if (isCrossing || isWalkingArea) {
         // draw internal lanes on top of junctions
         glTranslated(0, 0, GLO_JUNCTION + 0.1);
     } else {
@@ -424,42 +426,72 @@ GUILane::drawGL(const GUIVisualizationSettings& s) const {
     // set lane color
     if (!MSGlobals::gUseMesoSim) {
         setColor(s);
-        glPushName(getGlID()); // do not register for clicks in MESOSIM
     }
     // draw lane
     // check whether it is not too small
-    if (s.scale * s.laneWidthExaggeration < 1.) {
+    if (s.scale * exaggeration < 1.) {
         GLHelper::drawLine(myShape);
-        if (!MSGlobals::gUseMesoSim) {
-            glPopName();
-        }
         glPopMatrix();
     } else {
+        GUINet* net = (GUINet*) MSNet::getInstance();
         if (isRailway(myPermissions)) {
             // draw as railway
-            const SUMOReal halfRailWidth = 0.725 * s.laneWidthExaggeration;
+            const SUMOReal halfRailWidth = 0.725 * exaggeration;
             GLHelper::drawBoxLines(myShape, myShapeRotations, myShapeLengths, halfRailWidth);
             glColor3d(1, 1, 1);
             glTranslated(0, 0, .1);
             GLHelper::drawBoxLines(myShape, myShapeRotations, myShapeLengths, halfRailWidth - 0.2);
-            drawCrossties(s, s.laneWidthExaggeration);
+            if (!MSGlobals::gUseMesoSim) {
+                setColor(s);
+            }
+            drawCrossties(0.3 * exaggeration, 1 * exaggeration, 1 * exaggeration);
+        } else if (isCrossing) {
+            // determine priority to decide color
+            MSLink* link = MSLinkContHelper::getConnectingLink(*getLogicalPredecessorLane(), *this);
+            if (link->havePriority() || net->getLinkTLIndex(link) > 0) {
+                glColor3d(0.9, 0.9, 0.9);
+            } else {
+                glColor3d(0.1, 0.1, 0.1);
+            }
+            glTranslated(0, 0, .2);
+            drawCrossties(0.5, 1.0, getWidth() * 0.5);
+            glTranslated(0, 0, -.2);
+        } else if (isWalkingArea) {
+            glTranslated(0, 0, .2);
+            if (s.scale * exaggeration < 20.) {
+                GLHelper::drawFilledPoly(myShape, true);
+            } else {
+                GLHelper::drawFilledPolyTesselated(myShape, true);
+            }
+            glTranslated(0, 0, -.2);
+#ifdef GUILane_DEBUG_DRAW_WALKING_AREA_VERTICES
+            RGBColor color = RGBColor::fromHSV(RandHelper::rand(360), 1, 1);
+            glTranslated(0, 0, .4);
+            for (int i = 0; i < (int)myShape.size(); ++i) {
+                GLHelper::drawText(toString(i), myShape[i], GLO_JUNCTION,
+                                   80 / s.scale, color, 0);
+            }
+            glTranslated(0, 0, -.4);
+#endif
         } else {
             const SUMOReal laneWidth = isInternal ? myQuarterLaneWidth : myHalfLaneWidth;
-            mustDrawMarkings = !isInternal;
-            GLHelper::drawBoxLines(myShape, myShapeRotations, myShapeLengths, laneWidth * s.laneWidthExaggeration);
-        }
-        if (!MSGlobals::gUseMesoSim) {
-            glPopName();
+            mustDrawMarkings = !isInternal && myPermissions != 0 && myPermissions != SVC_PEDESTRIAN;
+            // recognize full transparency and simply don't draw
+            GLfloat color[4];
+            glGetFloatv(GL_CURRENT_COLOR, color);
+            if (color[3] > 0) {
+                const int cornerDetail = drawDetails ? s.scale * exaggeration : 0;
+                GLHelper::drawBoxLines(myShape, myShapeRotations, myShapeLengths, laneWidth * exaggeration, cornerDetail);
+            }
         }
         glPopMatrix();
         // draw ROWs (not for inner lanes)
-        if (!isInternal && drawDetails) {
+        if ((!isInternal || isCrossing) && drawDetails) {
             glPushMatrix();
             glTranslated(0, 0, GLO_JUNCTION); // must draw on top of junction shape
-            GUINet* net = (GUINet*) MSNet::getInstance();
-            glTranslated(0, 0, .2);
+            glTranslated(0, 0, .5);
             drawLinkRules(*net);
-            if (s.showLinkDecals && !isRailway(myPermissions)) {
+            if (s.showLinkDecals && !isRailway(myPermissions) && myPermissions != SVC_PEDESTRIAN) {
                 drawArrows();
             }
             if (s.showLane2Lane) {
@@ -478,10 +510,10 @@ GUILane::drawGL(const GUIVisualizationSettings& s) const {
         }
     }
     if (mustDrawMarkings && drawDetails) { // needs matrix reset
-        drawMarkings(s, s.laneWidthExaggeration);
+        drawMarkings(s, exaggeration);
     }
     // draw vehicles
-    if (s.scale > s.minVehicleSize) {
+    if (s.scale * s.vehicleSize.getExaggeration(s) > s.vehicleSize.minSize) {
         // retrieve vehicles from lane; disallow simulation
         const MSLane::VehCont& vehicles = getVehiclesSecure();
         for (MSLane::VehCont::const_iterator v = vehicles.begin(); v != vehicles.end(); ++v) {
@@ -497,20 +529,20 @@ GUILane::drawGL(const GUIVisualizationSettings& s) const {
         // allow lane simulation
         releaseVehicles();
     }
+    glPopName();
 }
 
 
 void
 GUILane::drawMarkings(const GUIVisualizationSettings& s, SUMOReal scale) const {
     glPushMatrix();
-    glPushName(0);
     glTranslated(0, 0, GLO_EDGE);
 #ifdef HAVE_INTERNAL
     if (!MSGlobals::gUseMesoSim)
 #endif
         setColor(s);
     // optionally draw inverse markings
-    if (myIndex > 0) {
+    if (myIndex > 0 && (myEdge->getLanes()[myIndex - 1]->getPermissions() & myPermissions) != 0) {
         SUMOReal mw = (myHalfLaneWidth + SUMO_const_laneOffset + .01) * scale;
         int e = (int) getShape().size() - 1;
         for (int i = 0; i < e; ++i) {
@@ -536,36 +568,30 @@ GUILane::drawMarkings(const GUIVisualizationSettings& s, SUMOReal scale) const {
         getShapeLengths(),
         (getHalfWidth() + SUMO_const_laneOffset) * scale);
     glPopMatrix();
-    glPopName();
 }
 
 
 void
-GUILane::drawCrossties(const GUIVisualizationSettings& s, SUMOReal scale) const {
+GUILane::drawCrossties(SUMOReal length, SUMOReal spacing, SUMOReal halfWidth) const {
     glPushMatrix();
-    glPushName(0);
-    if (!MSGlobals::gUseMesoSim) {
-        setColor(s);
-    }
     // draw on top of of the white area between the rails
     glTranslated(0, 0, 0.1);
     int e = (int) getShape().size() - 1;
     for (int i = 0; i < e; ++i) {
         glPushMatrix();
-        glTranslated(getShape()[i].x(), getShape()[i].y(), 0.1);
+        glTranslated(getShape()[i].x(), getShape()[i].y(), 0.0);
         glRotated(myShapeRotations[i], 0, 0, 1);
-        for (SUMOReal t = 0; t < myShapeLengths[i]; t += 1) {
+        for (SUMOReal t = 0; t < myShapeLengths[i]; t += spacing) {
             glBegin(GL_QUADS);
-            glVertex2d(-1 * scale, -t);
-            glVertex2d(-1 * scale, -t - 0.3);
-            glVertex2d(1.0 * scale, -t - 0.3);
-            glVertex2d(1.0 * scale, -t);
+            glVertex2d(-halfWidth, -t);
+            glVertex2d(-halfWidth, -t - length);
+            glVertex2d(halfWidth, -t - length);
+            glVertex2d(halfWidth, -t);
             glEnd();
         }
         glPopMatrix();
     }
     glPopMatrix();
-    glPopName();
 }
 
 // ------ inherited from GUIGlObject
@@ -592,14 +618,19 @@ GUIParameterTableWindow*
 GUILane::getParameterWindow(GUIMainWindow& app,
                             GUISUMOAbstractView&) {
     GUIParameterTableWindow* ret =
-        new GUIParameterTableWindow(app, *this, 5);
+        new GUIParameterTableWindow(app, *this, 11);
     // add items
     ret->mkItem("maxspeed [m/s]", false, getSpeedLimit());
     ret->mkItem("length [m]", false, myLength);
     ret->mkItem("street name", false, myEdge->getStreetName());
     ret->mkItem("stored traveltime [s]", true, new FunctionBinding<GUILane, SUMOReal>(this, &GUILane::getStoredEdgeTravelTime));
-    ret->mkItem("allowed vehicle class", false, getAllowedVehicleClassNames(myPermissions));
-    ret->mkItem("disallowed vehicle class", false, getAllowedVehicleClassNames(~myPermissions));
+    ret->mkItem("loaded weight", true, new FunctionBinding<GUILane, SUMOReal>(this, &GUILane::getLoadedEdgeWeight));
+    ret->mkItem("occupancy [%]", true, new FunctionBinding<GUILane, SUMOReal>(this, &GUILane::getBruttoOccupancy, 100.));
+    ret->mkItem("edge type", false, myEdge->getEdgeType());
+    ret->mkItem("priority", false, myEdge->getPriority());
+    ret->mkItem("allowed vehicle class", false, getVehicleClassNames(myPermissions));
+    ret->mkItem("disallowed vehicle class", false, getVehicleClassNames(~myPermissions));
+    ret->mkItem("permission code", false, myPermissions);
     // close building
     ret->closeBuilding();
     return ret;
@@ -651,12 +682,6 @@ GUILane::getEdgeLaneNumber() const {
 }
 
 
-void
-GUILane::setColor(const GUIVisualizationSettings& s) const {
-    GLHelper::setColor(s.laneColorer.getScheme().getColor(getColorValue(s.laneColorer.getActive())));
-}
-
-
 SUMOReal
 GUILane::getStoredEdgeTravelTime() const {
     MSEdgeWeightsStorage& ews = MSNet::getInstance()->getWeightsStorage();
@@ -664,14 +689,62 @@ GUILane::getStoredEdgeTravelTime() const {
         return -1;
     } else {
         SUMOReal value(0);
-        ews.retrieveExistingTravelTime(myEdge, 0, STEPS2TIME(MSNet::getInstance()->getCurrentTimeStep()), value);
+        ews.retrieveExistingTravelTime(myEdge, STEPS2TIME(MSNet::getInstance()->getCurrentTimeStep()), value);
         return value;
     }
 }
 
+
+SUMOReal
+GUILane::getLoadedEdgeWeight() const {
+    MSEdgeWeightsStorage& ews = MSNet::getInstance()->getWeightsStorage();
+    if (!ews.knowsEffort(myEdge)) {
+        return -1;
+    } else {
+        SUMOReal value(0);
+        ews.retrieveExistingEffort(myEdge, STEPS2TIME(MSNet::getInstance()->getCurrentTimeStep()), value);
+        return value;
+    }
+}
+
+
+void
+GUILane::setColor(const GUIVisualizationSettings& s) const {
+    const GUIColorer& c = s.laneColorer;
+    if (!setFunctionalColor(c.getActive())) {
+        GLHelper::setColor(c.getScheme().getColor(getColorValue(c.getActive())));
+    }
+}
+
+
+bool
+GUILane::setFunctionalColor(size_t activeScheme) const {
+    switch (activeScheme) {
+        case 18: {
+            SUMOReal hue = RAD2DEG(myShape.beginEndAngle()) + 180; // [0-360]
+            GLHelper::setColor(RGBColor::fromHSV(hue, 1., 1.));
+            return true;
+        }
+        default:
+            return false;
+    }
+}
+
+
 SUMOReal
 GUILane::getColorValue(size_t activeScheme) const {
     switch (activeScheme) {
+        case 0:
+            switch (myPermissions) {
+                case SVC_PEDESTRIAN:
+                    return 1;
+                case SVC_BICYCLE:
+                    return 2;
+                case 0:
+                    return 3;
+                default:
+                    return 0;
+            }
         case 1:
             return gSelected.isSelected(getType(), getGlID()) ||
                    gSelected.isSelected(GLO_EDGE, dynamic_cast<GUIEdge*>(myEdge)->getGlID());
@@ -710,13 +783,85 @@ GUILane::getColorValue(size_t activeScheme) const {
                 return -1;
             } else {
                 SUMOReal value(0);
-                ews.retrieveExistingTravelTime(myEdge, 0, 0, value);
+                ews.retrieveExistingTravelTime(myEdge, 0, value);
                 return 100 * myLength / value / getSpeedLimit();
             }
         }
         case 17: {
             return 1 / myLengthGeometryFactor;
         }
+        case 19: {
+            MSEdgeWeightsStorage& ews = MSNet::getInstance()->getWeightsStorage();
+            if (!ews.knowsEffort(myEdge)) {
+                return -1;
+            } else {
+                SUMOReal value(0);
+                ews.retrieveExistingEffort(myEdge, 0, value);
+                return value;
+            }
+        }
+        case 20: {
+            return myEdge->getPriority();
+        }
+    }
+    return 0;
+}
+
+
+SUMOReal
+GUILane::getScaleValue(size_t activeScheme) const {
+    switch (activeScheme) {
+        case 0:
+            return 0;
+        case 1:
+            return gSelected.isSelected(getType(), getGlID()) ||
+                   gSelected.isSelected(GLO_EDGE, dynamic_cast<GUIEdge*>(myEdge)->getGlID());
+        case 2:
+            return getSpeedLimit();
+        case 3:
+            return getBruttoOccupancy();
+        case 4:
+            return getNettoOccupancy();
+        case 5:
+            return firstWaitingTime();
+        case 6:
+            return getEdgeLaneNumber();
+        case 7:
+            return getCO2Emissions() / myLength;
+        case 8:
+            return getCOEmissions() / myLength;
+        case 9:
+            return getPMxEmissions() / myLength;
+        case 10:
+            return getNOxEmissions() / myLength;
+        case 11:
+            return getHCEmissions() / myLength;
+        case 12:
+            return getFuelConsumption() / myLength;
+        case 13:
+            return getHarmonoise_NoiseEmissions();
+        case 14: {
+            return getStoredEdgeTravelTime();
+        }
+        case 15: {
+            MSEdgeWeightsStorage& ews = MSNet::getInstance()->getWeightsStorage();
+            if (!ews.knowsTravelTime(myEdge)) {
+                return -1;
+            } else {
+                SUMOReal value(0);
+                ews.retrieveExistingTravelTime(myEdge, 0, value);
+                return 100 * myLength / value / getSpeedLimit();
+            }
+        }
+        case 16: {
+            return 1 / myLengthGeometryFactor;
+        }
+        case 17: {
+            return getLoadedEdgeWeight();
+        }
+        case 18: {
+            return myEdge->getPriority();
+        }
     }
     return 0;
 }
