@@ -5,11 +5,11 @@
 /// @author  Sascha Krieg
 /// @author  Michael Behrisch
 /// @date    Sept 2002
-/// @version $Id: GUIPerson.h 16560 2014-06-09 20:54:15Z behrisch $
+/// @version $Id: GUIPerson.h 17235 2014-11-03 10:53:02Z behrisch $
 ///
 // A MSVehicle extended by some values for usage within the gui
 /****************************************************************************/
-// SUMO, Simulation of Urban MObility; see http://sumo-sim.org/
+// SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
 // Copyright (C) 2001-2014 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
@@ -201,9 +201,6 @@ private:
     /// @brief sets the color according to the current scheme index and some vehicle function
     bool setFunctionalColor(size_t activeScheme) const;
 
-    /// @brief whether the person is visualized as stopped
-    bool myAmVisualizedAsStopped;
-
     /// @name drawing helper methods
     /// @{
     void drawAction_drawAsTriangle(const GUIVisualizationSettings& s) const;
