@@ -4,11 +4,11 @@
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @date    Sept 2002
-/// @version $Id: GUIVehicle.cpp 15844 2014-03-06 06:50:36Z namdre $
+/// @version $Id: GUIVehicle.cpp 17271 2014-11-05 11:12:48Z namdre $
 ///
 // A MSVehicle extended by some values for usage within the gui
 /****************************************************************************/
-// SUMO, Simulation of Urban MObility; see http://sumo-sim.org/
+// SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
 // Copyright (C) 2001-2014 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
@@ -33,13 +33,10 @@
 #include <cmath>
 #include <vector>
 #include <string>
-#ifdef HAVE_OSG
-#include <osg/ShapeDrawable>
-#include <osgview/GUIOSGView.h>
-#endif
 #include <foreign/polyfonts/polyfonts.h>
 #include <utils/common/StringUtils.h>
-#include <utils/common/SUMOVehicleParameter.h>
+#include <utils/vehicle/SUMOVehicleParameter.h>
+#include <utils/emissions/PollutantsInterface.h>
 #include <utils/gui/globjects/GLIncludes.h>
 #include <utils/gui/windows/GUISUMOAbstractView.h>
 #include <utils/gui/windows/GUIAppEnum.h>
@@ -57,6 +54,7 @@
 #include <microsim/MSAbstractLaneChangeModel.h>
 #include <microsim/devices/MSDevice_Vehroutes.h>
 #include <microsim/devices/MSDevice_Person.h>
+#include <microsim/devices/MSDevice_BTreceiver.h>
 #include <gui/GUIApplicationWindow.h>
 #include <gui/GUIGlobals.h>
 #include "GUIVehicle.h"
@@ -246,8 +244,7 @@ GUIVehicle::GUIVehiclePopupMenu::onCmdShowFoes(FXObject*, FXSelector, void*) {
  * GUIVehicle - methods
  * ----------------------------------------------------------------------- */
 GUIVehicle::GUIVehicle(SUMOVehicleParameter* pars, const MSRoute* route,
-                       const MSVehicleType* type,
-                       SUMOReal speedFactor) :
+                       const MSVehicleType* type, const SUMOReal speedFactor) :
     MSVehicle(pars, route, type, speedFactor),
     GUIGlObject(GLO_VEHICLE, pars->id) {
     // as it is possible to show all vehicle routes, we have to store them... (bug [ 2519761 ])
@@ -262,11 +259,6 @@ GUIVehicle::~GUIVehicle() {
     for (std::map<GUISUMOAbstractView*, int>::iterator i = myAdditionalVisualizations.begin(); i != myAdditionalVisualizations.end(); ++i) {
         while (i->first->removeAdditionalGLVisualisation(this));
     }
-#ifdef HAVE_OSG
-    for (std::map<GUIOSGView*, osg::ShapeDrawable*>::iterator i = myGeom.begin(); i != myGeom.end(); ++i) {
-        i->first->remove(this);
-    }
-#endif
     myLock.unlock();
     GLObjectValuePassConnector<SUMOReal>::removeObject(*this);
     delete myRoutes;
@@ -323,7 +315,7 @@ GUIParameterTableWindow*
 GUIVehicle::getParameterWindow(GUIMainWindow& app,
                                GUISUMOAbstractView&) {
     GUIParameterTableWindow* ret =
-        new GUIParameterTableWindow(app, *this, 34);
+        new GUIParameterTableWindow(app, *this, 35);
     // add items
     ret->mkItem("lane [id]", false, myLane->getID());
     ret->mkItem("position [m]", true,
@@ -344,12 +336,15 @@ GUIVehicle::getParameterWindow(GUIMainWindow& app,
     ret->mkItem("last lane change [s]", true,
                 new FunctionBinding<GUIVehicle, SUMOReal>(this, &GUIVehicle::getLastLaneChangeOffset));
     ret->mkItem("desired depart [s]", false, time2string(getParameter().depart));
-    if (getParameter().repetitionNumber > 0) {
-        ret->mkItem("left same route [#]", false, (unsigned int) getParameter().repetitionNumber);
+    if (getParameter().repetitionNumber < INT_MAX) {
+        ret->mkItem("remaining [#]", false, (unsigned int) getParameter().repetitionNumber - getParameter().repetitionsDone);
     }
     if (getParameter().repetitionOffset > 0) {
         ret->mkItem("insertion period [s]", false, time2string(getParameter().repetitionOffset));
     }
+    if (getParameter().repetitionProbability > 0) {
+        ret->mkItem("insertion probability", false, getParameter().repetitionProbability);
+    }
     ret->mkItem("stop info", false, getStopInfo());
     ret->mkItem("CO2 [mg/s]", true,
                 new FunctionBinding<GUIVehicle, SUMOReal>(this, &GUIVehicle::getCO2Emissions));
@@ -365,6 +360,14 @@ GUIVehicle::getParameterWindow(GUIMainWindow& app,
                 new FunctionBinding<GUIVehicle, SUMOReal>(this, &GUIVehicle::getFuelConsumption));
     ret->mkItem("noise (Harmonoise) [dB]", true,
                 new FunctionBinding<GUIVehicle, SUMOReal>(this, &GUIVehicle::getHarmonoise_NoiseEmissions));
+    std::ostringstream str;
+    for (std::vector<MSDevice*>::const_iterator i = myDevices.begin(); i != myDevices.end(); ++i) {
+        if (i != myDevices.begin()) {
+            str << ' ';
+        }
+        str << (*i)->getID().substr(0, (*i)->getID().find(getID()));
+    }
+    ret->mkItem("devices", false, str.str());
     ret->mkItem("parameters [key:val]", false, toString(getParameter().getMap()));
     ret->mkItem("", false, "");
     ret->mkItem("Type Information:", false, "");
@@ -372,7 +375,7 @@ GUIVehicle::getParameterWindow(GUIMainWindow& app,
     ret->mkItem("length", false, myType->getLength());
     ret->mkItem("minGap", false, myType->getMinGap());
     ret->mkItem("vehicle class", false, SumoVehicleClassStrings.getString(myType->getVehicleClass()));
-    ret->mkItem("emission class", false, SumoEmissionClassStrings.getString(myType->getEmissionClass()));
+    ret->mkItem("emission class", false, PollutantsInterface::getName(myType->getEmissionClass()));
     ret->mkItem("maximum speed [m/s]", false, getMaxSpeed());
     ret->mkItem("maximum acceleration [m/s^2]", false, getCarFollowModel().getMaxAccel());
     ret->mkItem("maximum deceleration [m/s^2]", false, getCarFollowModel().getMaxDecel());
@@ -476,6 +479,7 @@ GUIVehicle::drawAction_drawVehicleAsPoly(const GUIVisualizationSettings& s) cons
             glTranslated(0, 0, -.04);
             break;
         case SVS_BICYCLE:
+        case SVS_MOPED:
         case SVS_MOTORCYCLE: {
             glPushMatrix();
             glTranslated(.5, 0, 0);
@@ -520,9 +524,9 @@ GUIVehicle::drawAction_drawVehicleAsPoly(const GUIVisualizationSettings& s) cons
             drawPoly(vehiclePoly_DeliveryMediumRightGlass, 4.5);
             drawPoly(vehiclePoly_DeliveryMediumLeftGlass, 4.5);
             break;
-        case SVS_TRANSPORT:
-        case SVS_TRANSPORT_SEMITRAILER:
-        case SVS_TRANSPORT_1TRAILER:
+        case SVS_TRUCK:
+        case SVS_TRUCK_SEMITRAILER:
+        case SVS_TRUCK_1TRAILER:
             glScaled(1. / (length), 1, 1.);
             drawPoly(vehiclePoly_TransportBody, 4);
             glColor3d(0, 0, 0);
@@ -531,8 +535,8 @@ GUIVehicle::drawAction_drawVehicleAsPoly(const GUIVisualizationSettings& s) cons
             drawPoly(vehiclePoly_TransportLeftGlass, 4.5);
             break;
         case SVS_BUS:
-        case SVS_BUS_TROLLEY:
-        case SVS_BUS_CITY: {
+        case SVS_BUS_COACH:
+        case SVS_BUS_TROLLEY: {
             SUMOReal ml = length;
             glScaled(1. / (length), 1, 1.);
             glTranslated(0, 0, .04);
@@ -578,13 +582,9 @@ GUIVehicle::drawAction_drawVehicleAsPoly(const GUIVisualizationSettings& s) cons
             glTranslated(0, 0, -.045);
         }
         break;
-        case SVS_BUS_CITY_FLEXIBLE:
-        case SVS_BUS_OVERLAND:
+        case SVS_BUS_FLEXIBLE:
         case SVS_RAIL:
-        case SVS_RAIL_LIGHT:
-        case SVS_RAIL_CITY:
-        case SVS_RAIL_SLOW:
-        case SVS_RAIL_FAST:
+        case SVS_RAIL_CAR:
         case SVS_RAIL_CARGO:
             drawAction_drawCarriageClass(s, shape, false);
             break;
@@ -674,6 +674,7 @@ GUIVehicle::drawAction_drawVehicleAsPoly(const GUIVisualizationSettings& s) cons
             glVertex2d(0, 0);
             glEnd();
             break;
+        case SVS_MOPED:
         case SVS_MOTORCYCLE:
             //glScaled(length, 1, 1.);
             glBegin(GL_TRIANGLE_FAN);
@@ -709,15 +710,15 @@ GUIVehicle::drawAction_drawVehicleAsPoly(const GUIVisualizationSettings& s) cons
         case SVS_PASSENGER_VAN:
         case SVS_DELIVERY:
             break;
-        case SVS_TRANSPORT:
+        case SVS_TRUCK:
             GLHelper::setColor(current);
             GLHelper::drawBoxLine(Position(2.3, 0), 90., length - 2.3, .5);
             break;
-        case SVS_TRANSPORT_SEMITRAILER:
+        case SVS_TRUCK_SEMITRAILER:
             GLHelper::setColor(current);
             GLHelper::drawBoxLine(Position(2.8, 0), 90., length - 2.8, .5);
             break;
-        case SVS_TRANSPORT_1TRAILER: {
+        case SVS_TRUCK_1TRAILER: {
             GLHelper::setColor(current);
             SUMOReal l = length - 2.3;
             l = l / 2.;
@@ -739,14 +740,10 @@ GUIVehicle::drawAction_drawVehicleAsPoly(const GUIVisualizationSettings& s) cons
             glPopMatrix();
             break;
         case SVS_BUS:
-        case SVS_BUS_CITY:
-        case SVS_BUS_CITY_FLEXIBLE:
-        case SVS_BUS_OVERLAND:
+        case SVS_BUS_COACH:
+        case SVS_BUS_FLEXIBLE:
         case SVS_RAIL:
-        case SVS_RAIL_LIGHT:
-        case SVS_RAIL_CITY:
-        case SVS_RAIL_SLOW:
-        case SVS_RAIL_FAST:
+        case SVS_RAIL_CAR:
         case SVS_RAIL_CARGO:
         case SVS_E_VEHICLE:
         case SVS_ANT:
@@ -836,10 +833,11 @@ GUIVehicle::drawAction_drawVehicleAsImage(const GUIVisualizationSettings& s, SUM
     if (file != "") {
         int textureID = GUITexturesHelper::getTextureID(file);
         if (textureID > 0) {
+            const SUMOReal exaggeration = s.vehicleSize.getExaggeration(s);
             if (length < 0) {
-                length = getVehicleType().getLength() * s.vehicleExaggeration;
+                length = getVehicleType().getLength() * exaggeration;
             }
-            const SUMOReal halfWidth = getVehicleType().getWidth() / 2.0 * s.vehicleExaggeration;
+            const SUMOReal halfWidth = getVehicleType().getWidth() / 2.0 * exaggeration;
             GUITexturesHelper::drawTexturedBox(textureID, -halfWidth, 0, halfWidth, length);
             return true;
         }
@@ -851,24 +849,17 @@ GUIVehicle::drawAction_drawVehicleAsImage(const GUIVisualizationSettings& s, SUM
 bool
 GUIVehicle::drawAction_drawCarriageClass(const GUIVisualizationSettings& s, SUMOVehicleShape guiShape, bool asImage) const {
     switch (guiShape) {
-        case SVS_BUS_CITY_FLEXIBLE:
-        case SVS_BUS_OVERLAND:
+        case SVS_BUS_FLEXIBLE:
             drawAction_drawRailCarriages(s, 8.25, 0, 0, asImage); // 16.5 overall, 2 modules http://de.wikipedia.org/wiki/Ikarus_180
             break;
         case SVS_RAIL:
             drawAction_drawRailCarriages(s, 24.5, 1, 1, asImage); // http://de.wikipedia.org/wiki/UIC-Y-Wagen_%28DR%29
             break;
-        case SVS_RAIL_LIGHT:
+        case SVS_RAIL_CAR:
             drawAction_drawRailCarriages(s, 16.85, 1, 0, asImage); // 67.4m overall, 4 carriages http://de.wikipedia.org/wiki/DB-Baureihe_423
-            break;
-        case SVS_RAIL_CITY:
-            drawAction_drawRailCarriages(s, 5.71, 0, 0, asImage); // 40.0m overall, 7 modules http://de.wikipedia.org/wiki/Bombardier_Flexity_Berlin
-            break;
-        case SVS_RAIL_SLOW:
-            drawAction_drawRailCarriages(s, 9.44, 1, 1, asImage); // actually length of the locomotive http://de.wikipedia.org/wiki/KJI_Nr._20_und_21
-            break;
-        case SVS_RAIL_FAST:
-            drawAction_drawRailCarriages(s, 24.775, 0, 0, asImage); // http://de.wikipedia.org/wiki/ICE_3
+//            drawAction_drawRailCarriages(s, 5.71, 0, 0, asImage); // 40.0m overall, 7 modules http://de.wikipedia.org/wiki/Bombardier_Flexity_Berlin
+//            drawAction_drawRailCarriages(s, 9.44, 1, 1, asImage); // actually length of the locomotive http://de.wikipedia.org/wiki/KJI_Nr._20_und_21
+//            drawAction_drawRailCarriages(s, 24.775, 0, 0, asImage); // http://de.wikipedia.org/wiki/ICE_3
             break;
         case SVS_RAIL_CARGO:
             drawAction_drawRailCarriages(s, 13.86, 1, 0, asImage); // UIC 571-1 http://de.wikipedia.org/wiki/Flachwagen
@@ -944,7 +935,7 @@ GUIVehicle::drawGL(const GUIVisualizationSettings& s) const {
     // set lane color
     setColor(s);
     // scale
-    SUMOReal upscale = s.vehicleExaggeration;
+    const SUMOReal upscale = s.vehicleSize.getExaggeration(s);
     glScaled(upscale, upscale, 1);
     /*
         MSLCM_DK2004 &m2 = static_cast<MSLCM_DK2004&>(veh->getLaneChangeModel());
@@ -980,7 +971,7 @@ GUIVehicle::drawGL(const GUIVisualizationSettings& s) const {
             break;
     }
     if (s.drawMinGap) {
-        SUMOReal minGap = -getVehicleType().getMinGap();
+        const SUMOReal minGap = -getVehicleType().getMinGap();
         glColor3d(0., 1., 0.);
         glBegin(GL_LINES);
         glVertex2d(0., 0);
@@ -989,6 +980,11 @@ GUIVehicle::drawGL(const GUIVisualizationSettings& s) const {
         glVertex2d(.5, minGap);
         glEnd();
     }
+    MSDevice_BTreceiver* dev = static_cast<MSDevice_BTreceiver*>(getDevice(typeid(MSDevice_BTreceiver)));
+    if (dev != 0 && s.showBTRange) {
+        glColor3d(1., 0., 0.);
+        GLHelper::drawOutlineCircle(dev->getRange(), dev->getRange() - .2, 32);
+    }
     // draw the blinker and brakelights if wished
     if (s.showBlinker) {
         glTranslated(0, 0, .1);
@@ -997,11 +993,8 @@ GUIVehicle::drawGL(const GUIVisualizationSettings& s) const {
             case SVS_BICYCLE:
             case SVS_ANT:
             case SVS_RAIL:
-            case SVS_RAIL_LIGHT:
-            case SVS_RAIL_SLOW:
-            case SVS_RAIL_FAST:
             case SVS_RAIL_CARGO:
-                // only SVS_RAIL_CITY has blinkers and brake lights
+                // only SVS_RAIL_CAR has blinkers and brake lights
                 break;
             default:
                 drawAction_drawVehicleBlinker(*this, myCarriageLength);
@@ -1112,7 +1105,7 @@ GUIVehicle::drawGLAdditional(GUISUMOAbstractView* const parent, const GUIVisuali
                 }
                 const SUMOTime leaveTime = (*i).myLink->getLeaveTime(
                                                (*i).myArrivalTime, (*i).myArrivalSpeed, (*i).getLeaveSpeed(), getVehicleType().getLengthWithGap());
-                drawLinkItem(p, (*i).myArrivalTime, leaveTime, s.addExaggeration);
+                drawLinkItem(p, (*i).myArrivalTime, leaveTime, s.vehicleSize.getExaggeration(s));
                 // the time slot that ego vehicle uses when checking opened may
                 // differ from the one it requests in setApproaching
                 MSLink::ApproachingVehicleInformation avi = (*i).myLink->getApproaching(this);
@@ -1135,65 +1128,57 @@ GUIVehicle::drawLinkItem(const Position& pos, SUMOTime arrivalTime, SUMOTime lea
     glTranslated(-pos.x(), -pos.y(), .1);
 }
 
-const std::vector<MSVehicle::LaneQ>&
-GUIVehicle::getBestLanes() const {
-    myLock.lock();
-    const std::vector<MSVehicle::LaneQ>& ret = MSVehicle::getBestLanes();
-    myLock.unlock();
-    return ret;
-}
-
 
 void
 GUIVehicle::setColor(const GUIVisualizationSettings& s) const {
     const GUIColorer& c = s.vehicleColorer;
-    if (!setFunctionalColor(c.getActive())) {
+    if (!setFunctionalColor(c.getActive(), this)) {
         GLHelper::setColor(c.getScheme().getColor(getColorValue(c.getActive())));
     }
 }
 
 
 bool
-GUIVehicle::setFunctionalColor(size_t activeScheme) const {
+GUIVehicle::setFunctionalColor(size_t activeScheme, const MSBaseVehicle* veh) {
     switch (activeScheme) {
         case 0: {
-            if (getParameter().wasSet(VEHPARS_COLOR_SET)) {
-                GLHelper::setColor(getParameter().color);
+            if (veh->getParameter().wasSet(VEHPARS_COLOR_SET)) {
+                GLHelper::setColor(veh->getParameter().color);
                 return true;
             }
-            if (getVehicleType().wasSet(VTYPEPARS_COLOR_SET)) {
-                GLHelper::setColor(getVehicleType().getColor());
+            if (veh->getVehicleType().wasSet(VTYPEPARS_COLOR_SET)) {
+                GLHelper::setColor(veh->getVehicleType().getColor());
                 return true;
             }
-            if (&getRoute().getColor() != &RGBColor::DEFAULT_COLOR) {
-                GLHelper::setColor(getRoute().getColor());
+            if (&(veh->getRoute().getColor()) != &RGBColor::DEFAULT_COLOR) {
+                GLHelper::setColor(veh->getRoute().getColor());
                 return true;
             }
             return false;
         }
         case 2: {
-            if (getParameter().wasSet(VEHPARS_COLOR_SET)) {
-                GLHelper::setColor(getParameter().color);
+            if (veh->getParameter().wasSet(VEHPARS_COLOR_SET)) {
+                GLHelper::setColor(veh->getParameter().color);
                 return true;
             }
             return false;
         }
         case 3: {
-            if (getVehicleType().wasSet(VTYPEPARS_COLOR_SET)) {
-                GLHelper::setColor(getVehicleType().getColor());
+            if (veh->getVehicleType().wasSet(VTYPEPARS_COLOR_SET)) {
+                GLHelper::setColor(veh->getVehicleType().getColor());
                 return true;
             }
             return false;
         }
         case 4: {
-            if (&getRoute().getColor() != &RGBColor::DEFAULT_COLOR) {
-                GLHelper::setColor(getRoute().getColor());
+            if (&(veh->getRoute().getColor()) != &RGBColor::DEFAULT_COLOR) {
+                GLHelper::setColor(veh->getRoute().getColor());
                 return true;
             }
             return false;
         }
         case 5: {
-            Position p = getRoute().getEdges()[0]->getLanes()[0]->getShape()[0];
+            Position p = veh->getRoute().getEdges()[0]->getLanes()[0]->getShape()[0];
             const Boundary& b = ((GUINet*) MSNet::getInstance())->getBoundary();
             Position center = b.getCenter();
             SUMOReal hue = 180. + atan2(center.x() - p.x(), center.y() - p.y()) * 180. / PI;
@@ -1202,7 +1187,7 @@ GUIVehicle::setFunctionalColor(size_t activeScheme) const {
             return true;
         }
         case 6: {
-            Position p = getRoute().getEdges().back()->getLanes()[0]->getShape()[-1];
+            Position p = veh->getRoute().getEdges().back()->getLanes()[0]->getShape()[-1];
             const Boundary& b = ((GUINet*) MSNet::getInstance())->getBoundary();
             Position center = b.getCenter();
             SUMOReal hue = 180. + atan2(center.x() - p.x(), center.y() - p.y()) * 180. / PI;
@@ -1211,8 +1196,8 @@ GUIVehicle::setFunctionalColor(size_t activeScheme) const {
             return true;
         }
         case 7: {
-            Position pb = getRoute().getEdges()[0]->getLanes()[0]->getShape()[0];
-            Position pe = getRoute().getEdges().back()->getLanes()[0]->getShape()[-1];
+            Position pb = veh->getRoute().getEdges()[0]->getLanes()[0]->getShape()[0];
+            Position pe = veh->getRoute().getEdges().back()->getLanes()[0]->getShape()[-1];
             const Boundary& b = ((GUINet*) MSNet::getInstance())->getBoundary();
             SUMOReal hue = 180. + atan2(pb.x() - pe.x(), pb.y() - pe.y()) * 180. / PI;
             Position minp(b.xmin(), b.ymin());
@@ -1315,12 +1300,13 @@ GUIVehicle::drawRoute(const GUIVisualizationSettings& s, int routeNo, SUMOReal d
         colors[3] = 0;
     }
     glColor3dv(colors);
+    const SUMOReal exaggeration = s.vehicleSize.getExaggeration(s);
     if (routeNo == 0) {
-        drawRouteHelper(*myRoute, s.vehicleExaggeration);
+        drawRouteHelper(*myRoute, exaggeration);
         return;
     }
     --routeNo; // only prior routes are stored
-    drawRouteHelper(*myRoutes->getRoute(routeNo), s.vehicleExaggeration);
+    drawRouteHelper(*myRoutes->getRoute(routeNo), exaggeration);
 }
 
 
@@ -1394,13 +1380,19 @@ void
 GUIVehicle::drawAction_drawRailCarriages(const GUIVisualizationSettings& s, SUMOReal defaultLength, SUMOReal carriageGap, int firstPassengerCarriage, bool asImage) const {
     RGBColor current = GLHelper::getColor();
     RGBColor darker = current.changedBrightness(-51);
-    const SUMOReal length = getVehicleType().getLength() * s.vehicleExaggeration;
-    const SUMOReal halfWidth = getVehicleType().getWidth() / 2.0 * s.vehicleExaggeration;
+    const SUMOReal exaggeration = s.vehicleSize.getExaggeration(s);
+    defaultLength *= exaggeration;
+    if (exaggeration == 0) {
+        return;
+    }
+    carriageGap *= exaggeration;
+    const SUMOReal length = getVehicleType().getLength() * exaggeration;
+    const SUMOReal halfWidth = getVehicleType().getWidth() / 2.0 * exaggeration;
     glPopMatrix(); // undo scaling and 90 degree rotation
     glPopMatrix(); // undo initial translation and rotation
     GLHelper::setColor(darker);
-    const SUMOReal xCornerCut = 0.3;
-    const SUMOReal yCornerCut = 0.4;
+    const SUMOReal xCornerCut = 0.3 * exaggeration;
+    const SUMOReal yCornerCut = 0.4 * exaggeration;
     // round to closest integer
     const int numCarriages = floor(length / (defaultLength + carriageGap) + 0.5);
     assert(numCarriages > 0);
@@ -1427,7 +1419,7 @@ GUIVehicle::drawAction_drawRailCarriages(const GUIVisualizationSettings& s, SUMO
         while (carriageOffset < 0) {
             MSLane* prev = getPreviousLane(lane, furtherIndex);
             if (prev != lane) {
-                carriageOffset += lane->getLength();
+                carriageOffset += prev->getLength();
             } else {
                 // no lane available for drawing.
                 carriageOffset = 0;
@@ -1435,11 +1427,21 @@ GUIVehicle::drawAction_drawRailCarriages(const GUIVisualizationSettings& s, SUMO
             lane = prev;
         }
         while (carriageBackOffset < 0) {
-            backLane = getPreviousLane(backLane, backFurtherIndex);
-            carriageBackOffset += backLane->getLength();
+            MSLane* prev = getPreviousLane(backLane, backFurtherIndex);
+            if (prev != backLane) {
+                carriageBackOffset += prev->getLength();
+            } else {
+                // no lane available for drawing.
+                carriageBackOffset = 0;
+            }
+            backLane = prev;
         }
         front = lane->getShape().positionAtOffset2D(carriageOffset);
         back = backLane->getShape().positionAtOffset2D(carriageBackOffset);
+        if (front == back) {
+            // no place for drawing available
+            continue;
+        }
         angle = atan2((front.x() - back.x()), (back.y() - front.y())) * (SUMOReal) 180.0 / (SUMOReal) PI;
         if (i >= firstPassengerCarriage) {
             computeSeats(front, back, requiredSeats);
@@ -1543,19 +1545,30 @@ GUIVehicle::selectBlockingFoes() const {
             continue;
         }
         std::vector<const SUMOVehicle*> blockingFoes;
-        dpi.myLink->opened(dpi.myArrivalTime, dpi.myArrivalSpeed, dpi.getLeaveSpeed(), getVehicleType().getLengthWithGap(),
+        std::vector<const MSPerson*> blockingPersons;
+        dpi.myLink->opened(dpi.myArrivalTime, dpi.myArrivalSpeed, dpi.getLeaveSpeed(), getVehicleType().getLength(),
                            getImpatience(), getCarFollowModel().getMaxDecel(), getWaitingTime(), &blockingFoes);
         for (std::vector<const SUMOVehicle*>::const_iterator it = blockingFoes.begin(); it != blockingFoes.end(); ++it) {
             gSelected.select(static_cast<const GUIVehicle*>(*it)->getGlID());
         }
 #ifdef HAVE_INTERNAL_LANES
-        const MSLink::LinkLeaders linkLeaders = (dpi.myLink)->getLeaderInfo(dist, getVehicleType().getMinGap());
+        const MSLink::LinkLeaders linkLeaders = (dpi.myLink)->getLeaderInfo(dist, getVehicleType().getMinGap(), &blockingPersons);
         for (MSLink::LinkLeaders::const_iterator it = linkLeaders.begin(); it != linkLeaders.end(); ++it) {
             // the vehicle to enter the junction first has priority
-            const MSVehicle* leader = it->first.first;
-            if ((static_cast<const GUIVehicle*>(leader))->myLinkLeaders.count(getID()) == 0) {
-                // leader isn't already following us, now we follow it
-                gSelected.select(static_cast<const GUIVehicle*>(leader)->getGlID());
+            const GUIVehicle* leader = dynamic_cast<const GUIVehicle*>(it->vehAndGap.first);
+            if (leader != 0) {
+                if (leader->myLinkLeaders[dpi.myLink->getJunction()].count(getID()) == 0) {
+                    // leader isn't already following us, now we follow it
+                    gSelected.select(leader->getGlID());
+                }
+            } else {
+                for (std::vector<const MSPerson*>::iterator it_p = blockingPersons.begin(); it_p != blockingPersons.end(); ++it_p) {
+                    const GUIPerson* foe = dynamic_cast<const GUIPerson*>(*it_p);
+                    if (foe != 0) {
+                        gSelected.select(foe->getGlID());
+                        //std::cout << SIMTIME << " veh=" << getID() << " is blocked on link " << dpi.myLink->getRespondIndex() << " to " << dpi.myLink->getViaLaneOrLane()->getID() << " by pedestrian. dist=" << it->second << "\n";
+                    }
+                }
             }
         }
 #endif
@@ -1563,15 +1576,5 @@ GUIVehicle::selectBlockingFoes() const {
     }
 }
 
-
-#ifdef HAVE_OSG
-void
-GUIVehicle::updateColor(GUIOSGView* view) {
-    const GUIVisualizationSettings* s = view->getVisualisationSettings();
-    const RGBColor& col = s->vehicleColorer.getScheme().getColor(getColorValue(s->vehicleColorer.getActive()));
-    myGeom[view]->setColor(osg::Vec4(col.red() / 255., col.green() / 255., col.blue() / 255., col.alpha() / 255.));
-}
-#endif
-
 /****************************************************************************/
 
