@@ -4,11 +4,11 @@
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @date    Wed, 10. Dec 2003
-/// @version $Id: GUIVehicleControl.cpp 16418 2014-05-23 06:57:58Z behrisch $
+/// @version $Id: GUIVehicleControl.cpp 17235 2014-11-03 10:53:02Z behrisch $
 ///
 // The class responsible for building and deletion of vehicles (gui-version)
 /****************************************************************************/
-// SUMO, Simulation of Urban MObility; see http://sumo-sim.org/
+// SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
 // Copyright (C) 2001-2014 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
@@ -31,6 +31,7 @@
 #endif
 
 #include <utils/foxtools/MFXMutex.h>
+#include <microsim/MSRouteHandler.h>
 #include "GUIVehicleControl.h"
 #include "GUIVehicle.h"
 #include "GUINet.h"
@@ -58,13 +59,14 @@ GUIVehicleControl::~GUIVehicleControl() {
 
 SUMOVehicle*
 GUIVehicleControl::buildVehicle(SUMOVehicleParameter* defs,
-                                const MSRoute* route, const MSVehicleType* type) {
+                                const MSRoute* route, const MSVehicleType* type,
+                                const bool ignoreStopErrors, const bool fromRouteFile) {
     myLoadedVehNo++;
-    if (myMaxRandomDepartOffset > 0) {
-        // round to the closest usable simulation step
-        defs->depart += DELTA_T * int((myVehicleParamsRNG.rand((int)myMaxRandomDepartOffset) + 0.5 * DELTA_T) / DELTA_T);
+    if (fromRouteFile) {
+        defs->depart += computeRandomDepartOffset();
     }
-    MSVehicle* built = new GUIVehicle(defs, route, type, type->computeChosenSpeedDeviation(myVehicleParamsRNG));
+    MSVehicle* built = new GUIVehicle(defs, route, type, type->computeChosenSpeedDeviation(fromRouteFile ? MSRouteHandler::getParsingRNG() : 0));
+    built->addStops(ignoreStopErrors);
     MSNet::getInstance()->informVehicleStateListener(built, MSNet::VEHICLE_STATE_BUILT);
     return built;
 }
